<?php
/**
 * VW Maintenance Services Theme Customizer
 *
 * @package VW Maintenance Services
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function vw_maintenance_services_custom_controls() {

    load_template( trailingslashit( get_template_directory() ) . '/inc/custom-controls.php' );
}
add_action( 'customize_register', 'vw_maintenance_services_custom_controls' );

function vw_maintenance_services_customize_register( $wp_customize ) {

	load_template( trailingslashit( get_template_directory() ) . '/inc/icon-picker.php' );

	$wp_customize->get_setting( 'blogname' )->transport = 'postMessage'; 
	$wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'blogname', array( 
		'selector' => '.logo .site-title a', 
	 	'render_callback' => 'vw_maintenance_services_customize_partial_blogname', 
	)); 

	$wp_customize->selective_refresh->add_partial( 'blogdescription', array( 
		'selector' => 'p.site-description', 
		'render_callback' => 'vw_maintenance_services_customize_partial_blogdescription', 
	));

	//add home page setting pannel
	$VWMaintenanceServicesParentPanel = new VW_Maintenance_Services_WP_Customize_Panel( $wp_customize, 'vw_maintenance_services_panel_id', array(
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => esc_html__( 'VW Settings', 'vw-maintenance-services' ),
		'priority' => 10,
	));

	$wp_customize->add_panel( $VWMaintenanceServicesParentPanel );

	$HomePageParentPanel = new VW_Maintenance_Services_WP_Customize_Panel( $wp_customize, 'vw_maintenance_services_homepage_panel', array(
		'title' => __( 'Homepage Settings', 'vw-maintenance-services' ),
		'panel' => 'vw_maintenance_services_panel_id',
	));

	$wp_customize->add_panel( $HomePageParentPanel );

	//Topbar
	$wp_customize->add_section( 'vw_maintenance_services_topbar', array(
    	'title'      => __( 'Topbar Settings', 'vw-maintenance-services' ),
		'panel' => 'vw_maintenance_services_homepage_panel'
	) );

  // Header Background color
	$wp_customize->add_setting('vw_maintenance_services_header_background_color', array(
		'default'           => '#f3f6fa',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'vw_maintenance_services_header_background_color', array(
		'label'    => __('Header Background Color', 'vw-maintenance-services'),
		'section'  => 'header_image',
	)));

	$wp_customize->add_setting('vw_maintenance_services_header_img_position',array(
	  'default' => 'center top',
	  'transport' => 'refresh',
	  'sanitize_callback' => 'vw_maintenance_services_sanitize_choices'
	));
	$wp_customize->add_control('vw_maintenance_services_header_img_position',array(
		'type' => 'select',
		'label' => __('Header Image Position','vw-maintenance-services'),
		'section' => 'header_image',
		'choices' 	=> array(
			'left top' 		=> esc_html__( 'Top Left', 'vw-maintenance-services' ),
			'center top'   => esc_html__( 'Top', 'vw-maintenance-services' ),
			'right top'   => esc_html__( 'Top Right', 'vw-maintenance-services' ),
			'left center'   => esc_html__( 'Left', 'vw-maintenance-services' ),
			'center center'   => esc_html__( 'Center', 'vw-maintenance-services' ),
			'right center'   => esc_html__( 'Right', 'vw-maintenance-services' ),
			'left bottom'   => esc_html__( 'Bottom Left', 'vw-maintenance-services' ),
			'center bottom'   => esc_html__( 'Bottom', 'vw-maintenance-services' ),
			'right bottom'   => esc_html__( 'Bottom Right', 'vw-maintenance-services' ),
		),
	));

	//Sticky Header
	$wp_customize->add_setting( 'vw_maintenance_services_sticky_header',array(
    'default' => 0,
    'transport' => 'refresh',
    'sanitize_callback' => 'vw_maintenance_services_switch_sanitization'
  ) );
  $wp_customize->add_control( new VW_Maintenance_Services_Toggle_Switch_Custom_Control( $wp_customize, 'vw_maintenance_services_sticky_header',array(
        'label' => esc_html__( 'Sticky Header','vw-maintenance-services' ),
        'section' => 'vw_maintenance_services_topbar'
  )));

  $wp_customize->add_setting('vw_maintenance_services_sticky_header_padding',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_sticky_header_padding',array(
		'label'	=> __('Sticky Header Padding','vw-maintenance-services'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-maintenance-services'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-maintenance-services' ),
        ),
		'section'=> 'vw_maintenance_services_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'vw_maintenance_services_search_hide_show',array(
      'default' => 1,
      'transport' => 'refresh',
      'sanitize_callback' => 'vw_maintenance_services_switch_sanitization'
  ));  
  $wp_customize->add_control( new VW_Maintenance_Services_Toggle_Switch_Custom_Control( $wp_customize, 'vw_maintenance_services_search_hide_show',array(
      'label' => esc_html__( 'Show / Hide Search','vw-maintenance-services' ),
      'section' => 'vw_maintenance_services_topbar'
  )));

  $wp_customize->add_setting('vw_maintenance_services_search_icon',array(
		'default'	=> 'fas fa-search',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new VW_Maintenance_Services_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_maintenance_services_search_icon',array(
		'label'	=> __('Add Search Icon','vw-maintenance-services'),
		'transport' => 'refresh',
		'section'	=> 'vw_maintenance_services_topbar',
		'setting'	=> 'vw_maintenance_services_search_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('vw_maintenance_services_search_close_icon',array(
		'default'	=> 'fa fa-window-close',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new VW_Maintenance_Services_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_maintenance_services_search_close_icon',array(
		'label'	=> __('Add Search Close Icon','vw-maintenance-services'),
		'transport' => 'refresh',
		'section'	=> 'vw_maintenance_services_topbar',
		'setting'	=> 'vw_maintenance_services_search_close_icon',
		'type'		=> 'icon'
	)));

  $wp_customize->add_setting('vw_maintenance_services_search_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_search_font_size',array(
		'label'	=> __('Search Font Size','vw-maintenance-services'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-maintenance-services'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-maintenance-services' ),
        ),
		'section'=> 'vw_maintenance_services_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_maintenance_services_search_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_search_padding_top_bottom',array(
		'label'	=> __('Search Padding Top Bottom','vw-maintenance-services'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-maintenance-services'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-maintenance-services' ),
        ),
		'section'=> 'vw_maintenance_services_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_maintenance_services_search_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_search_padding_left_right',array(
		'label'	=> __('Search Padding Left Right','vw-maintenance-services'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-maintenance-services'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-maintenance-services' ),
        ),
		'section'=> 'vw_maintenance_services_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'vw_maintenance_services_search_border_radius', array(
		'default'              => "",
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_maintenance_services_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_maintenance_services_search_border_radius', array(
		'label'       => esc_html__( 'Search Border Radius','vw-maintenance-services' ),
		'section'     => 'vw_maintenance_services_topbar',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting('vw_maintenance_services_search_placeholder',array(
   'default' => esc_html__('Search','vw-maintenance-services'),
   'sanitize_callback'	=> 'sanitize_text_field'
  ));
  $wp_customize->add_control('vw_maintenance_services_search_placeholder',array(
   'type' => 'text',
   'label' => __('Search Placeholder Text','vw-maintenance-services'),
   'section' => 'vw_maintenance_services_topbar'
  ));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('vw_maintenance_services_header_call', array( 
		'selector' => 'p.call-no', 
		'render_callback' => 'vw_maintenance_services_customize_partial_vw_maintenance_services_header_call', 
	));

  $wp_customize->add_setting('vw_maintenance_services_phone_no_icon',array(
		'default'	=> 'fas fa-phone',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new VW_Maintenance_Services_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_maintenance_services_phone_no_icon',array(
		'label'	=> __('Add Phone Icon','vw-maintenance-services'),
		'transport' => 'refresh',
		'section'	=> 'vw_maintenance_services_topbar',
		'setting'	=> 'vw_maintenance_services_phone_no_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('vw_maintenance_services_header_call_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_header_call_text',array(
		'label'	=> __('Add Phone Text.','vw-maintenance-services'),
		'input_attrs' => array(
            'placeholder' => __( 'Toll Free', 'vw-maintenance-services' ),
        ),
		'section'=> 'vw_maintenance_services_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_maintenance_services_header_call',array(
		'default'=> '',
		'sanitize_callback'	=> 'vw_maintenance_services_sanitize_phone_number'
	));
	$wp_customize->add_control('vw_maintenance_services_header_call',array(
		'label'	=> __('Add Phone No.','vw-maintenance-services'),
		'input_attrs' => array(
            'placeholder' => __( '+07 123 125 1234', 'vw-maintenance-services' ),
        ),
		'section'=> 'vw_maintenance_services_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_maintenance_services_top_btn_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_top_btn_text',array(
		'label'	=> __('Add Button Text','vw-maintenance-services'),
		'input_attrs' => array(
            'placeholder' => __( 'GET APPOINTMENT', 'vw-maintenance-services' ),
        ),
		'section'=> 'vw_maintenance_services_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_maintenance_services_top_btn_url',array(
		'default'=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('vw_maintenance_services_top_btn_url',array(
		'label'	=> __('Add Button URL','vw-maintenance-services'),
		'input_attrs' => array(
            'placeholder' => __( 'https://www.example.com', 'vw-maintenance-services' ),
        ),
		'section'=> 'vw_maintenance_services_topbar',
		'type'=> 'url'
	));

	//Menus Settings
	$wp_customize->add_section( 'vw_maintenance_services_menu_section' , array(
  	'title' => __( 'Menus Settings', 'vw-maintenance-services' ),
		'panel' => 'vw_maintenance_services_homepage_panel'
	) );

	$wp_customize->add_setting('vw_maintenance_services_navigation_menu_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_navigation_menu_font_size',array(
		'label'	=> __('Menus Font Size','vw-maintenance-services'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-maintenance-services'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-maintenance-services' ),
        ),
		'section'=> 'vw_maintenance_services_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_maintenance_services_navigation_menu_font_weight',array(
    'default' => 500,
    'transport' => 'refresh',
    'sanitize_callback' => 'vw_maintenance_services_sanitize_choices'
	));
	$wp_customize->add_control('vw_maintenance_services_navigation_menu_font_weight',array(
    'type' => 'select',
    'label' => __('Menus Font Weight','vw-maintenance-services'),
    'section' => 'vw_maintenance_services_menu_section',
    'choices' => array(
    	'100' => __('100','vw-maintenance-services'),
        '200' => __('200','vw-maintenance-services'),
        '300' => __('300','vw-maintenance-services'),
        '400' => __('400','vw-maintenance-services'),
        '500' => __('500','vw-maintenance-services'),
        '600' => __('600','vw-maintenance-services'),
        '700' => __('700','vw-maintenance-services'),
        '800' => __('800','vw-maintenance-services'),
        '900' => __('900','vw-maintenance-services'),
        ),
	) );

	// text trasform
	$wp_customize->add_setting('vw_maintenance_services_menu_text_transform',array(
		'default'=> 'Uppercase',
		'sanitize_callback'	=> 'vw_maintenance_services_sanitize_choices'
	));
	$wp_customize->add_control('vw_maintenance_services_menu_text_transform',array(
		'type' => 'radio',
		'label'	=> __('Menus Text Transform','vw-maintenance-services'),
		'choices' => array(
        'Uppercase' => __('Uppercase','vw-maintenance-services'),
        'Capitalize' => __('Capitalize','vw-maintenance-services'),
        'Lowercase' => __('Lowercase','vw-maintenance-services'),
        ),
		'section'=> 'vw_maintenance_services_menu_section',
	));

	$wp_customize->add_setting('vw_maintenance_services_menus_item_style',array(
	  'default' => '',
	  'transport' => 'refresh',
	  'sanitize_callback' => 'vw_maintenance_services_sanitize_choices'
	));
	$wp_customize->add_control('vw_maintenance_services_menus_item_style',array(
			'type' => 'select',
			'section' => 'vw_maintenance_services_menu_section',
			'label' => __('Menu Item Hover Style','vw-maintenance-services'),
			'choices' => array(
			    'None' => __('None','vw-maintenance-services'),
			    'Zoom In' => __('Zoom In','vw-maintenance-services'),
        ),
	) );

	$wp_customize->add_setting('vw_maintenance_services_header_menus_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'vw_maintenance_services_header_menus_color', array(
		'label'    => __('Menus Color', 'vw-maintenance-services'),
		'section'  => 'vw_maintenance_services_menu_section',
	)));

	$wp_customize->add_setting('vw_maintenance_services_header_menus_hover_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'vw_maintenance_services_header_menus_hover_color', array(
		'label'    => __('Menus Hover Color', 'vw-maintenance-services'),
		'section'  => 'vw_maintenance_services_menu_section',
	)));

	$wp_customize->add_setting('vw_maintenance_services_header_submenus_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'vw_maintenance_services_header_submenus_color', array(
		'label'    => __('Sub Menus Color', 'vw-maintenance-services'),
		'section'  => 'vw_maintenance_services_menu_section',
	)));

	$wp_customize->add_setting('vw_maintenance_services_header_submenus_hover_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'vw_maintenance_services_header_submenus_hover_color', array(
		'label'    => __('Sub Menus Hover Color', 'vw-maintenance-services'),
		'section'  => 'vw_maintenance_services_menu_section',
	)));

	//Social links
	$wp_customize->add_section(
		'vw_maintenance_services_social_links', array(
			'title'		=>	__('Social Links', 'vw-maintenance-services'),
			'priority'	=>	null,
			'panel'		=>	'vw_maintenance_services_homepage_panel'
		)
	);

	$wp_customize->add_setting('vw_maintenance_services_social_icons',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_social_icons',array(
		'label' =>  __('Steps to setup social icons','vw-maintenance-services'),
		'description' => __('<p>1. Go to Dashboard >> Appearance >> Widgets</p>
			<p>2. Add Vw Social Icon Widget in Social Icon Widget area.</p>
			<p>3. Add social icons url and save.</p>','vw-maintenance-services'),
		'section'=> 'vw_maintenance_services_social_links',
		'type'=> 'hidden'
	));
	$wp_customize->add_setting('vw_maintenance_services_social_icon_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_social_icon_btn',array(
		'description' => "<a target='_blank' href='". admin_url('widgets.php') ." '>Setup Social Icons</a>",
		'section'=> 'vw_maintenance_services_social_links',
		'type'=> 'hidden'
	));
    
	//Slider
	$wp_customize->add_section( 'vw_maintenance_services_slidersettings' , array(
  	'title'      => __( 'Slider Section', 'vw-maintenance-services' ),
  	'description' => __('Free theme has 3 slides options, For unlimited slides and more options </br> <a class="go-pro-btn" target="blank" href="https://www.vwthemes.com/themes/wordpress-maintenance-service-theme/">GET PRO</a>','vw-maintenance-services'),
	'panel' => 'vw_maintenance_services_homepage_panel'
	) );

	$wp_customize->add_setting( 'vw_maintenance_services_slider_hide_show',array(
    'default' => 0,
    'transport' => 'refresh',
    'sanitize_callback' => 'vw_maintenance_services_switch_sanitization'
  ));  
  $wp_customize->add_control( new VW_Maintenance_Services_Toggle_Switch_Custom_Control( $wp_customize, 'vw_maintenance_services_slider_hide_show',array(
    'label' => esc_html__( 'Show / Hide Slider','vw-maintenance-services' ),
    'section' => 'vw_maintenance_services_slidersettings'
  )));

  $wp_customize->add_setting('vw_maintenance_services_slider_type',array(
    'default' => 'Default slider',
    'sanitize_callback' => 'vw_maintenance_services_sanitize_choices'
	) );
	$wp_customize->add_control('vw_maintenance_services_slider_type', array(
    'type' => 'select',
    'label' => __('Slider Type','vw-maintenance-services'),
    'section' => 'vw_maintenance_services_slidersettings',
    'choices' => array(
      'Default slider' => __('Default slider','vw-maintenance-services'),
      'Advance slider' => __('Advance slider','vw-maintenance-services'),
    ),
	));

	$wp_customize->add_setting('vw_maintenance_services_advance_slider_shortcode',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_advance_slider_shortcode',array(
		'label'	=> __('Add Slider Shortcode','vw-maintenance-services'),
		'section'=> 'vw_maintenance_services_slidersettings',
		'type'=> 'text',
		'active_callback' => 'vw_maintenance_services_advance_slider'
	));

  //Selective Refresh
  $wp_customize->selective_refresh->add_partial('vw_maintenance_services_slider_hide_show',array(
	'selector'        => '#slider .inner_carousel h1',
	'render_callback' => 'vw_maintenance_services_customize_partial_vw_maintenance_services_slider_hide_show',
	));

	for ( $count = 1; $count <= 3; $count++ ) {
	$wp_customize->add_setting( 'vw_maintenance_services_slider_page' . $count, array(
		'default'           => '',
		'sanitize_callback' => 'vw_maintenance_services_sanitize_dropdown_pages'
	) );
	$wp_customize->add_control( 'vw_maintenance_services_slider_page' . $count, array(
		'label'    => __( 'Select Slider Page', 'vw-maintenance-services' ),
		'description' => __('Slider image size (1500 x 590)','vw-maintenance-services'),
		'section'  => 'vw_maintenance_services_slidersettings',
		'type'     => 'dropdown-pages',
		'active_callback' => 'vw_maintenance_services_default_slider'
	) );
	}

	$wp_customize->add_setting('vw_maintenance_services_slider_button_text',array(
		'default'=> 'READ MORE',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_slider_button_text',array(
		'label'	=> __('Add Slider Button Text','vw-maintenance-services'),
		'input_attrs' => array(
            'placeholder' => __( 'READ MORE', 'vw-maintenance-services' ),
        ),
		'section'=> 'vw_maintenance_services_slidersettings',
		'type'=> 'text',
		'active_callback' => 'vw_maintenance_services_default_slider'
	));

	$wp_customize->add_setting('vw_maintenance_services_slider_button_link',array(
        'default'=> '',
        'sanitize_callback' => 'esc_url_raw'
    ));
    $wp_customize->add_control('vw_maintenance_services_slider_button_link',array(
        'label' => esc_html__('Add Button Link','vw-maintenance-services'),
        'input_attrs' => array(
            'placeholder' => esc_html__( 'www.example-info.com', 'vw-maintenance-services' ),
        ),
        'section'=> 'vw_maintenance_services_slidersettings',
        'type'=> 'url'
    ));

	$wp_customize->add_setting('vw_maintenance_services_slider_bttn_icon',array(
		'default'	=> 'fa fa-angle-right',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new VW_Maintenance_Services_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_maintenance_services_slider_bttn_icon',array(
		'label'	=> __('Add Slider Button Icon','vw-maintenance-services'),
		'transport' => 'refresh',
		'section'	=> 'vw_maintenance_services_slidersettings',
		'setting'	=> 'vw_maintenance_services_slider_bttn_icon',
		'type'		=> 'icon',
		'active_callback' => 'vw_maintenance_services_default_slider'
	)));

	//content layout
	$wp_customize->add_setting('vw_maintenance_services_slider_content_option',array(
    'default' => 'Left',
    'sanitize_callback' => 'vw_maintenance_services_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Maintenance_Services_Image_Radio_Control($wp_customize, 'vw_maintenance_services_slider_content_option', array(
    'type' => 'select',
    'label' => __('Slider Content Layouts','vw-maintenance-services'),
    'section' => 'vw_maintenance_services_slidersettings',
    'choices' => array(
        'Left' => esc_url(get_template_directory_uri()).'/assets/images/slider-content1.png',
        'Center' => esc_url(get_template_directory_uri()).'/assets/images/slider-content2.png',
        'Right' => esc_url(get_template_directory_uri()).'/assets/images/slider-content3.png',
    ),
    'active_callback' => 'vw_maintenance_services_default_slider'
	)));

  //Slider content padding
  $wp_customize->add_setting('vw_maintenance_services_slider_content_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_slider_content_padding_top_bottom',array(
		'label'	=> __('Slider Content Padding Top Bottom','vw-maintenance-services'),
		'description'	=> __('Enter a value in %. Example:20%','vw-maintenance-services'),
		'input_attrs' => array(
            'placeholder' => __( '50%', 'vw-maintenance-services' ),
        ),
		'section'=> 'vw_maintenance_services_slidersettings',
		'type'=> 'text',
		'active_callback' => 'vw_maintenance_services_default_slider'
	));

	$wp_customize->add_setting('vw_maintenance_services_slider_content_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_slider_content_padding_left_right',array(
		'label'	=> __('Slider Content Padding Left Right','vw-maintenance-services'),
		'description'	=> __('Enter a value in %. Example:20%','vw-maintenance-services'),
		'input_attrs' => array(
            'placeholder' => __( '50%', 'vw-maintenance-services' ),
        ),
		'section'=> 'vw_maintenance_services_slidersettings',
		'type'=> 'text',
		'active_callback' => 'vw_maintenance_services_default_slider'
	));

  //Slider excerpt
	$wp_customize->add_setting( 'vw_maintenance_services_slider_excerpt_number', array(
		'default'              => 30,
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_maintenance_services_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_maintenance_services_slider_excerpt_number', array(
		'label'       => esc_html__( 'Slider Excerpt length','vw-maintenance-services' ),
		'section'     => 'vw_maintenance_services_slidersettings',
		'type'        => 'range',
		'settings'    => 'vw_maintenance_services_slider_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),'active_callback' => 'vw_maintenance_services_default_slider'
	) );

	//Slider height
	$wp_customize->add_setting('vw_maintenance_services_slider_height',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_slider_height',array(
		'label'	=> __('Slider Height','vw-maintenance-services'),
		'description'	=> __('Specify the slider height (px).','vw-maintenance-services'),
		'input_attrs' => array(
            'placeholder' => __( '500px', 'vw-maintenance-services' ),
        ),
		'section'=> 'vw_maintenance_services_slidersettings',
		'type'=> 'text',
		'active_callback' => 'vw_maintenance_services_default_slider'
	));

	$wp_customize->add_setting( 'vw_maintenance_services_slider_speed', array(
		'default'  => 4000,
		'sanitize_callback'	=> 'vw_maintenance_services_sanitize_float'
	) );
	$wp_customize->add_control( 'vw_maintenance_services_slider_speed', array(
		'label' => esc_html__('Slider Transition Speed','vw-maintenance-services'),
		'section' => 'vw_maintenance_services_slidersettings',
		'type'  => 'number',
		'active_callback' => 'vw_maintenance_services_default_slider'
	) );

	//Opacity
	$wp_customize->add_setting('vw_maintenance_services_slider_opacity_color',array(
      'default'              => 0.7,
      'sanitize_callback' => 'vw_maintenance_services_sanitize_choices'
	));

	$wp_customize->add_control( 'vw_maintenance_services_slider_opacity_color', array(
		'label'       => esc_html__( 'Slider Image Opacity','vw-maintenance-services' ),
		'section'     => 'vw_maintenance_services_slidersettings',
		'type'        => 'select',
		'settings'    => 'vw_maintenance_services_slider_opacity_color',
		'choices' => array(
	      '0' =>  esc_attr('0','vw-maintenance-services'),
	      '0.1' =>  esc_attr('0.1','vw-maintenance-services'),
	      '0.2' =>  esc_attr('0.2','vw-maintenance-services'),
	      '0.3' =>  esc_attr('0.3','vw-maintenance-services'),
	      '0.4' =>  esc_attr('0.4','vw-maintenance-services'),
	      '0.5' =>  esc_attr('0.5','vw-maintenance-services'),
	      '0.6' =>  esc_attr('0.6','vw-maintenance-services'),
	      '0.7' =>  esc_attr('0.7','vw-maintenance-services'),
	      '0.8' =>  esc_attr('0.8','vw-maintenance-services'),
	      '0.9' =>  esc_attr('0.9','vw-maintenance-services')
		),'active_callback' => 'vw_maintenance_services_default_slider'
	));

	$wp_customize->add_setting( 'vw_maintenance_services_slider_image_overlay',array(
		'default' => 1,
  	'transport' => 'refresh',
  	'sanitize_callback' => 'vw_maintenance_services_switch_sanitization'
	));
	$wp_customize->add_control( new VW_Maintenance_Services_Toggle_Switch_Custom_Control( $wp_customize, 'vw_maintenance_services_slider_image_overlay',array(
  	'label' => esc_html__( 'Slider Image Overlay','vw-maintenance-services' ),
  	'section' => 'vw_maintenance_services_slidersettings',
  	'active_callback' => 'vw_maintenance_services_default_slider'
 	)));

 	$wp_customize->add_setting('vw_maintenance_services_slider_image_overlay_color', array(
		'default'           => '#838384',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'vw_maintenance_services_slider_image_overlay_color', array(
		'label'    => __('Slider Image Overlay Color', 'vw-maintenance-services'),
		'section'  => 'vw_maintenance_services_slidersettings',
		'active_callback' => 'vw_maintenance_services_default_slider'
	)));

	//Services section
	$wp_customize->add_section( 'vw_maintenance_services_services_section' , array(
    	'title'      => __( 'Our Services Section', 'vw-maintenance-services' ),
    	'description' => __('For more options of service section </br><a class="go-pro-btn" target="blank" href="https://www.vwthemes.com/themes/wordpress-maintenance-service-theme/">GET PRO</a>','vw-maintenance-services'),
		'priority'   => null,
		'panel' => 'vw_maintenance_services_homepage_panel'
	) );

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'vw_maintenance_services_section_title', array( 
		'selector' => '#services-section h2', 
		'render_callback' => 'vw_maintenance_services_customize_partial_vw_maintenance_services_section_title',
	));

	$wp_customize->add_setting('vw_maintenance_services_section_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_maintenance_services_section_title',array(
		'label'	=> __('Section Title','vw-maintenance-services'),
		'input_attrs' => array(
            'placeholder' => __( 'Our Services', 'vw-maintenance-services' ),
        ),
		'section'=> 'vw_maintenance_services_services_section',
		'type'=> 'text'
	));

	$categories = get_categories();
	$cat_post = array();
	$cat_post[]= 'select';
	$i = 0;	
	foreach($categories as $category){
		if($i==0){
			$default = $category->slug;
			$i++;
		}
		$cat_post[$category->slug] = $category->name;
	}

	$wp_customize->add_setting('vw_maintenance_services_left_service',array(
		'default'	=> 'select',
		'sanitize_callback' => 'vw_maintenance_services_sanitize_choices',
	));
	$wp_customize->add_control('vw_maintenance_services_left_service',array(
		'type'    => 'select',
		'choices' => $cat_post,
		'label' => __('Select Category to display left services','vw-maintenance-services'),
		'description' => __('Image Size (250 x 250)','vw-maintenance-services'),
		'section' => 'vw_maintenance_services_services_section',
	));

	$wp_customize->add_setting( 'vw_maintenance_services_about', array(
		'default'           => '',
		'sanitize_callback' => 'vw_maintenance_services_sanitize_dropdown_pages'
	) );
	$wp_customize->add_control( 'vw_maintenance_services_about', array(
		'label'    => __( 'Select About us Page', 'vw-maintenance-services' ),
		'description' => __('Image size (350 x 500)','vw-maintenance-services'),
		'section'  => 'vw_maintenance_services_services_section',
		'type'     => 'dropdown-pages'
	) );

	$categories = get_categories();
	$cat_post = array();
	$cat_post[]= 'select';
	$i = 0;	
	foreach($categories as $category){
		if($i==0){
			$default = $category->slug;
			$i++;
		}
		$cat_post[$category->slug] = $category->name;
	}

	$wp_customize->add_setting('vw_maintenance_services_right_service',array(
		'default'	=> 'select',
		'sanitize_callback' => 'vw_maintenance_services_sanitize_choices',
	));
	$wp_customize->add_control('vw_maintenance_services_right_service',array(
		'type'    => 'select',
		'choices' => $cat_post,
		'label' => __('Select Category to display right services','vw-maintenance-services'),
		'description' => __('Image Size (250 x 250)','vw-maintenance-services'),
		'section' => 'vw_maintenance_services_services_section',
	));

	//Services excerpt
	$wp_customize->add_setting( 'vw_maintenance_services_services_excerpt_number', array(
		'default'              => 30,
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_maintenance_services_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_maintenance_services_services_excerpt_number', array(
		'label'       => esc_html__( 'Services Excerpt length','vw-maintenance-services' ),
		'section'     => 'vw_maintenance_services_services_section',
		'type'        => 'range',
		'settings'    => 'vw_maintenance_services_services_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//features Section
	$wp_customize->add_section('vw_maintenance_services_features', array(
		'title'       => __('Features Section', 'vw-maintenance-services'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','vw-maintenance-services'),
		'priority'    => null,
		'panel'       => 'vw_maintenance_services_homepage_panel',
	));

	$wp_customize->add_setting('vw_maintenance_services_features_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_features_text',array(
		'description' => __('<p>1. More options for features section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for features section.</p>','vw-maintenance-services'),
		'section'=> 'vw_maintenance_services_features',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('vw_maintenance_services_features_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_features_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=vw_maintenance_services_guide') ." '>More Info</a>",
		'section'=> 'vw_maintenance_services_features',
		'type'=> 'hidden'
	));

	//project Section
	$wp_customize->add_section('vw_maintenance_services_project', array(
		'title'       => __('Project Section', 'vw-maintenance-services'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','vw-maintenance-services'),
		'priority'    => null,
		'panel'       => 'vw_maintenance_services_homepage_panel',
	));

	$wp_customize->add_setting('vw_maintenance_services_project_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_project_text',array(
		'description' => __('<p>1. More options for project section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for project section.</p>','vw-maintenance-services'),
		'section'=> 'vw_maintenance_services_project',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('vw_maintenance_services_project_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_project_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=vw_maintenance_services_guide') ." '>More Info</a>",
		'section'=> 'vw_maintenance_services_project',
		'type'=> 'hidden'
	));

	//About Maintenance Section
	$wp_customize->add_section('vw_maintenance_services_about', array(
		'title'       => __('About Maintenance Section', 'vw-maintenance-services'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','vw-maintenance-services'),
		'priority'    => null,
		'panel'       => 'vw_maintenance_services_homepage_panel',
	));

	$wp_customize->add_setting('vw_maintenance_services_about_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_about_text',array(
		'description' => __('<p>1. More options for about maintenance section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for about maintenance section.</p>','vw-maintenance-services'),
		'section'=> 'vw_maintenance_services_about',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('vw_maintenance_services_about_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_about_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=vw_maintenance_services_guide') ." '>More Info</a>",
		'section'=> 'vw_maintenance_services_about',
		'type'=> 'hidden'
	));

	//team Section
	$wp_customize->add_section('vw_maintenance_services_team', array(
		'title'       => __('Team Section', 'vw-maintenance-services'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','vw-maintenance-services'),
		'priority'    => null,
		'panel'       => 'vw_maintenance_services_homepage_panel',
	));

	$wp_customize->add_setting('vw_maintenance_services_team_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_team_text',array(
		'description' => __('<p>1. More options for team section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for team section.</p>','vw-maintenance-services'),
		'section'=> 'vw_maintenance_services_team',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('vw_maintenance_services_team_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_team_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=vw_maintenance_services_guide') ." '>More Info</a>",
		'section'=> 'vw_maintenance_services_team',
		'type'=> 'hidden'
	));

	//testimonials Section
	$wp_customize->add_section('vw_maintenance_services_testimonials', array(
		'title'       => __('Testimonials Section', 'vw-maintenance-services'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','vw-maintenance-services'),
		'priority'    => null,
		'panel'       => 'vw_maintenance_services_homepage_panel',
	));

	$wp_customize->add_setting('vw_maintenance_services_testimonials_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_testimonials_text',array(
		'description' => __('<p>1. More options for testimonials section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for testimonials section.</p>','vw-maintenance-services'),
		'section'=> 'vw_maintenance_services_testimonials',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('vw_maintenance_services_testimonials_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_testimonials_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=vw_maintenance_services_guide') ." '>More Info</a>",
		'section'=> 'vw_maintenance_services_testimonials',
		'type'=> 'hidden'
	));

	//partners Section
	$wp_customize->add_section('vw_maintenance_services_partners', array(
		'title'       => __('Partners Section', 'vw-maintenance-services'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','vw-maintenance-services'),
		'priority'    => null,
		'panel'       => 'vw_maintenance_services_homepage_panel',
	));

	$wp_customize->add_setting('vw_maintenance_services_partners_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_partners_text',array(
		'description' => __('<p>1. More options for partners section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for partners section.</p>','vw-maintenance-services'),
		'section'=> 'vw_maintenance_services_partners',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('vw_maintenance_services_partners_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_partners_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=vw_maintenance_services_guide') ." '>More Info</a>",
		'section'=> 'vw_maintenance_services_partners',
		'type'=> 'hidden'
	));

	//call now Section
	$wp_customize->add_section('vw_maintenance_services_call_now', array(
		'title'       => __('Call Now Section', 'vw-maintenance-services'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','vw-maintenance-services'),
		'priority'    => null,
		'panel'       => 'vw_maintenance_services_homepage_panel',
	));

	$wp_customize->add_setting('vw_maintenance_services_call_now_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_call_now_text',array(
		'description' => __('<p>1. More options for call now section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for call now section.</p>','vw-maintenance-services'),
		'section'=> 'vw_maintenance_services_call_now',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('vw_maintenance_services_call_now_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_call_now_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=vw_maintenance_services_guide') ." '>More Info</a>",
		'section'=> 'vw_maintenance_services_call_now',
		'type'=> 'hidden'
	));

	//latest news Section
	$wp_customize->add_section('vw_maintenance_services_latest_news', array(
		'title'       => __('Latest News Section', 'vw-maintenance-services'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','vw-maintenance-services'),
		'priority'    => null,
		'panel'       => 'vw_maintenance_services_homepage_panel',
	));

	$wp_customize->add_setting('vw_maintenance_services_latest_news_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_latest_news_text',array(
		'description' => __('<p>1. More options for latest news section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for latest news section.</p>','vw-maintenance-services'),
		'section'=> 'vw_maintenance_services_latest_news',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('vw_maintenance_services_latest_news_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_latest_news_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=vw_maintenance_services_guide') ." '>More Info</a>",
		'section'=> 'vw_maintenance_services_latest_news',
		'type'=> 'hidden'
	));

	//appointment Section
	$wp_customize->add_section('vw_maintenance_services_appointment', array(
		'title'       => __('Appointment Section', 'vw-maintenance-services'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','vw-maintenance-services'),
		'priority'    => null,
		'panel'       => 'vw_maintenance_services_homepage_panel',
	));

	$wp_customize->add_setting('vw_maintenance_services_appointment_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_appointment_text',array(
		'description' => __('<p>1. More options for appointment section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for appointment section.</p>','vw-maintenance-services'),
		'section'=> 'vw_maintenance_services_appointment',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('vw_maintenance_services_appointment_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_appointment_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=vw_maintenance_services_guide') ." '>More Info</a>",
		'section'=> 'vw_maintenance_services_appointment',
		'type'=> 'hidden'
	));

	//Footer Text
	$wp_customize->add_section('vw_maintenance_services_footer',array(
		'title'	=> __('Footer','vw-maintenance-services'),
		'description' => __('For more options of footer section </br><a class="go-pro-btn" target="blank" href="https://www.vwthemes.com/themes/wordpress-maintenance-service-theme/">GET PRO</a>','vw-maintenance-services'),
		'panel' => 'vw_maintenance_services_homepage_panel',
	));	
	
	$wp_customize->add_setting( 'vw_maintenance_services_footer_hide_show',array(
      'default' => 1,
      'transport' => 'refresh',
      'sanitize_callback' => 'vw_maintenance_services_switch_sanitization'
  ));
  $wp_customize->add_control( new VW_Maintenance_Services_Toggle_Switch_Custom_Control( $wp_customize, 'vw_maintenance_services_footer_hide_show',array(
    'label' => esc_html__( 'Show / Hide Footer','vw-maintenance-services' ),
    'section' => 'vw_maintenance_services_footer'
  )));

   // font size
	$wp_customize->add_setting('vw_maintenance_services_button_footer_font_size',array(
		'default'=> 25,
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_button_footer_font_size',array(
		'label'	=> __('Footer Heading Font Size','vw-maintenance-services'),
  		'type'        => 'number',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
		'section'=> 'vw_maintenance_services_footer',
	));

	$wp_customize->add_setting('vw_maintenance_services_button_footer_heading_letter_spacing',array(
		'default'=> 1,
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_button_footer_heading_letter_spacing',array(
		'label'	=> __('Heading Letter Spacing','vw-maintenance-services'),
  		'type'        => 'number',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
	),
		'section'=> 'vw_maintenance_services_footer',
	));

	// text trasform
	$wp_customize->add_setting('vw_maintenance_services_button_footer_text_transform',array(
		'default'=> 'Capitalize',
		'sanitize_callback'	=> 'vw_maintenance_services_sanitize_choices'
	));
	$wp_customize->add_control('vw_maintenance_services_button_footer_text_transform',array(
		'type' => 'radio',
		'label'	=> __('Heading Text Transform','vw-maintenance-services'),
		'choices' => array(
      'Uppercase' => __('Uppercase','vw-maintenance-services'),
      'Capitalize' => __('Capitalize','vw-maintenance-services'),
      'Lowercase' => __('Lowercase','vw-maintenance-services'),
    ),
		'section'=> 'vw_maintenance_services_footer',
	));

	$wp_customize->add_setting('vw_maintenance_services_footer_heading_weight',array(
        'default' => '',
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_maintenance_services_sanitize_choices'
	));
	$wp_customize->add_control('vw_maintenance_services_footer_heading_weight',array(
        'type' => 'select',
        'label' => __('Heading Font Weight','vw-maintenance-services'),
        'section' => 'vw_maintenance_services_footer',
        'choices' => array(
        	'100' => __('100','vw-maintenance-services'),
            '200' => __('200','vw-maintenance-services'),
            '300' => __('300','vw-maintenance-services'),
            '400' => __('400','vw-maintenance-services'),
            '500' => __('500','vw-maintenance-services'),
            '600' => __('600','vw-maintenance-services'),
            '700' => __('700','vw-maintenance-services'),
            '800' => __('800','vw-maintenance-services'),
            '900' => __('900','vw-maintenance-services'),
        ),
	) );

  $wp_customize->add_setting('vw_maintenance_services_footer_template',array(
      'default'	=> esc_html('vw_maintenance_services-footer-one'),
      'sanitize_callback'	=> 'vw_maintenance_services_sanitize_choices'
  ));
  $wp_customize->add_control('vw_maintenance_services_footer_template',array(
          'label'	=> esc_html__('Footer style','vw-maintenance-services'),
          'section'	=> 'vw_maintenance_services_footer',
          'setting'	=> 'vw_maintenance_services_footer_template',
          'type' => 'select',
          'choices' => array(
              'vw_maintenance_services-footer-one' => esc_html__('Style 1', 'vw-maintenance-services'),
              'vw_maintenance_services-footer-two' => esc_html__('Style 2', 'vw-maintenance-services'),
              'vw_maintenance_services-footer-three' => esc_html__('Style 3', 'vw-maintenance-services'),
              'vw_maintenance_services-footer-four' => esc_html__('Style 4', 'vw-maintenance-services'),
              'vw_maintenance_services-footer-five' => esc_html__('Style 5', 'vw-maintenance-services'),
              )
  ));

	$wp_customize->add_setting('vw_maintenance_services_footer_background_color', array(
		'default'           => '#303133',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'vw_maintenance_services_footer_background_color', array(
		'label'    => __('Footer Background Color', 'vw-maintenance-services'),
		'section'  => 'vw_maintenance_services_footer',
	)));

	$wp_customize->add_setting('vw_maintenance_services_footer_background_image',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw',
	));
	$wp_customize->add_control( new WP_Customize_Image_Control($wp_customize,'vw_maintenance_services_footer_background_image',array(
        'label' => __('Footer Background Image','vw-maintenance-services'),
        'section' => 'vw_maintenance_services_footer'
	)));

	$wp_customize->add_setting('vw_maintenance_services_footer_img_position',array(
	  'default' => 'center center',
	  'transport' => 'refresh',
	  'sanitize_callback' => 'vw_maintenance_services_sanitize_choices'
	));
	$wp_customize->add_control('vw_maintenance_services_footer_img_position',array(
		'type' => 'select',
		'label' => __('Footer Image Position','vw-maintenance-services'),
		'section' => 'vw_maintenance_services_footer',
		'choices' 	=> array(
			'left top' 		=> esc_html__( 'Top Left', 'vw-maintenance-services' ),
			'center top'   => esc_html__( 'Top', 'vw-maintenance-services' ),
			'right top'   => esc_html__( 'Top Right', 'vw-maintenance-services' ),
			'left center'   => esc_html__( 'Left', 'vw-maintenance-services' ),
			'center center'   => esc_html__( 'Center', 'vw-maintenance-services' ),
			'right center'   => esc_html__( 'Right', 'vw-maintenance-services' ),
			'left bottom'   => esc_html__( 'Bottom Left', 'vw-maintenance-services' ),
			'center bottom'   => esc_html__( 'Bottom', 'vw-maintenance-services' ),
			'right bottom'   => esc_html__( 'Bottom Right', 'vw-maintenance-services' ),
		),
	));

	// Footer
	$wp_customize->add_setting('vw_maintenance_services_img_footer',array(
		'default'=> 'scroll',
		'sanitize_callback'	=> 'vw_maintenance_services_sanitize_choices'
	));
	$wp_customize->add_control('vw_maintenance_services_img_footer',array(
		'type' => 'select',
		'label'	=> __('Footer Background Attatchment','vw-maintenance-services'),
		'choices' => array(
        'fixed' => __('fixed','vw-maintenance-services'),
        'scroll' => __('scroll','vw-maintenance-services'),
        ),
		'section'=> 'vw_maintenance_services_footer',
	));

	$wp_customize->add_setting('vw_maintenance_services_footer_widgets_heading',array(
    'default' => 'Left',
    'transport' => 'refresh',
    'sanitize_callback' => 'vw_maintenance_services_sanitize_choices'
	));
	$wp_customize->add_control('vw_maintenance_services_footer_widgets_heading',array(
    'type' => 'select',
    'label' => __('Footer Widget Heading','vw-maintenance-services'),
    'section' => 'vw_maintenance_services_footer',
    'choices' => array(
    	'Left' => __('Left','vw-maintenance-services'),
        'Center' => __('Center','vw-maintenance-services'),
        'Right' => __('Right','vw-maintenance-services')
        ),
	) );

	$wp_customize->add_setting('vw_maintenance_services_footer_widgets_content',array(
    'default' => 'Left',
    'transport' => 'refresh',
    'sanitize_callback' => 'vw_maintenance_services_sanitize_choices'
	));
	$wp_customize->add_control('vw_maintenance_services_footer_widgets_content',array(
    'type' => 'select',
    'label' => __('Footer Widget Content','vw-maintenance-services'),
    'section' => 'vw_maintenance_services_footer',
    'choices' => array(
    		'Left' => __('Left','vw-maintenance-services'),
        'Center' => __('Center','vw-maintenance-services'),
        'Right' => __('Right','vw-maintenance-services')
        ),
	) );

	// footer padding
	$wp_customize->add_setting('vw_maintenance_services_footer_padding',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_footer_padding',array(
		'label'	=> __('Footer Top Bottom Padding','vw-maintenance-services'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-maintenance-services'),
		'input_attrs' => array(
      'placeholder' => __( '10px', 'vw-maintenance-services' ),
    ),
		'section'=> 'vw_maintenance_services_footer',
		'type'=> 'text'
	));

  // footer social icon
	$wp_customize->add_setting( 'vw_maintenance_services_footer_icon',array(
		'default' => false,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_maintenance_services_switch_sanitization'
  ) );
	$wp_customize->add_control( new VW_Maintenance_Services_Toggle_Switch_Custom_Control( $wp_customize, 'vw_maintenance_services_footer_icon',array(
		'label' => esc_html__( 'Footer Social Icon','vw-maintenance-services' ),
		'section' => 'vw_maintenance_services_footer'
  )));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('vw_maintenance_services_footer_text', array( 
		'selector' => '#footer-2 .copyright p', 
		'render_callback' => 'vw_maintenance_services_customize_partial_vw_maintenance_services_footer_text', 
	));

	$wp_customize->add_setting( 'vw_maintenance_services_copyright_hide_show',array(
      'default' => 1,
      'transport' => 'refresh',
      'sanitize_callback' => 'vw_maintenance_services_switch_sanitization'
    ));
    $wp_customize->add_control( new VW_Maintenance_Services_Toggle_Switch_Custom_Control( $wp_customize, 'vw_maintenance_services_copyright_hide_show',array(
      'label' => esc_html__( 'Show / Hide Copyright','vw-maintenance-services' ),
      'section' => 'vw_maintenance_services_footer'
    )));

	$wp_customize->add_setting('vw_maintenance_services_copyright_background_color', array(
		'default'           => '#fb7f7f',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'vw_maintenance_services_copyright_background_color', array(
		'label'    => __('Copyright Background Color', 'vw-maintenance-services'),
		'section'  => 'vw_maintenance_services_footer',
	)));
	
	$wp_customize->add_setting('vw_maintenance_services_footer_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_maintenance_services_footer_text',array(
		'label'	=> __('Copyright Text','vw-maintenance-services'),
		'input_attrs' => array(
            'placeholder' => __( 'Copyright 2019, .....', 'vw-maintenance-services' ),
        ),
		'section'=> 'vw_maintenance_services_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_maintenance_services_copyright_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_copyright_font_size',array(
		'label'	=> __('Copyright Font Size','vw-maintenance-services'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-maintenance-services'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-maintenance-services' ),
        ),
		'section'=> 'vw_maintenance_services_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_maintenance_services_copyright_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_copyright_padding_top_bottom',array(
		'label'	=> __('Copyright Padding Top Bottom','vw-maintenance-services'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-maintenance-services'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-maintenance-services' ),
        ),
		'section'=> 'vw_maintenance_services_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_maintenance_services_copyright_alignment',array(
    'default' => 'center',
    'sanitize_callback' => 'vw_maintenance_services_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Maintenance_Services_Image_Radio_Control($wp_customize, 'vw_maintenance_services_copyright_alignment', array(
    'type' => 'select',
    'label' => __('Copyright Alignment','vw-maintenance-services'),
    'section' => 'vw_maintenance_services_footer',
    'settings' => 'vw_maintenance_services_copyright_alignment',
    'choices' => array(
        'left' => esc_url(get_template_directory_uri()).'/assets/images/copyright1.png',
        'center' => esc_url(get_template_directory_uri()).'/assets/images/copyright2.png',
        'right' => esc_url(get_template_directory_uri()).'/assets/images/copyright3.png'
    ))));

	$wp_customize->add_setting( 'vw_maintenance_services_hide_show_scroll',array(
		'default' => 1,
  	'transport' => 'refresh',
  	'sanitize_callback' => 'vw_maintenance_services_switch_sanitization'
  ));  
  $wp_customize->add_control( new VW_Maintenance_Services_Toggle_Switch_Custom_Control( $wp_customize, 'vw_maintenance_services_hide_show_scroll',array(
  	'label' => esc_html__( 'Show / Hide Scroll To Top','vw-maintenance-services' ),
  	'section' => 'vw_maintenance_services_footer'
  )));

  //Selective Refresh
	$wp_customize->selective_refresh->add_partial('vw_maintenance_services_scroll_to_top_icon', array( 
		'selector' => '.scrollup i', 
		'render_callback' => 'vw_maintenance_services_customize_partial_vw_maintenance_services_scroll_to_top_icon', 
	));

  $wp_customize->add_setting('vw_maintenance_services_scroll_to_top_icon',array(
		'default'	=> 'fas fa-angle-up',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new VW_Maintenance_Services_Fontawesome_Icon_Chooser(
  $wp_customize,'vw_maintenance_services_scroll_to_top_icon',array(
		'label'	=> __('Add Scroll to Top Icon','vw-maintenance-services'),
		'transport' => 'refresh',
		'section'	=> 'vw_maintenance_services_footer',
		'setting'	=> 'vw_maintenance_services_scroll_to_top_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('vw_maintenance_services_scroll_to_top_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_scroll_to_top_font_size',array(
		'label'	=> __('Icon Font Size','vw-maintenance-services'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-maintenance-services'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-maintenance-services' ),
        ),
		'section'=> 'vw_maintenance_services_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_maintenance_services_scroll_to_top_padding',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_scroll_to_top_padding',array(
		'label'	=> __('Icon Top Bottom Padding','vw-maintenance-services'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-maintenance-services'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-maintenance-services' ),
        ),
		'section'=> 'vw_maintenance_services_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_maintenance_services_scroll_to_top_width',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_scroll_to_top_width',array(
		'label'	=> __('Icon Width','vw-maintenance-services'),
		'description'	=> __('Enter a value in pixels Example:20px','vw-maintenance-services'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-maintenance-services' ),
        ),
		'section'=> 'vw_maintenance_services_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_maintenance_services_scroll_to_top_height',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_scroll_to_top_height',array(
		'label'	=> __('Icon Height','vw-maintenance-services'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-maintenance-services'),
		'input_attrs' => array(
    'placeholder' => __( '10px', 'vw-maintenance-services' ),),
		'section'=> 'vw_maintenance_services_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'vw_maintenance_services_scroll_to_top_border_radius', array(
		'default'              => '',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_maintenance_services_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_maintenance_services_scroll_to_top_border_radius', array(
		'label'       => esc_html__( 'Icon Border Radius','vw-maintenance-services' ),
		'section'     => 'vw_maintenance_services_footer',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );	

	$wp_customize->add_setting('vw_maintenance_services_scroll_top_alignment',array(
    'default' => 'Right',
    'sanitize_callback' => 'vw_maintenance_services_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Maintenance_Services_Image_Radio_Control($wp_customize, 'vw_maintenance_services_scroll_top_alignment', array(
        'type' => 'select',
        'label' => __('Scroll To Top','vw-maintenance-services'),
        'section' => 'vw_maintenance_services_footer',
        'settings' => 'vw_maintenance_services_scroll_top_alignment',
        'choices' => array(
            'Left' => esc_url(get_template_directory_uri()).'/assets/images/layout1.png',
            'Center' => esc_url(get_template_directory_uri()).'/assets/images/layout2.png',
            'Right' => esc_url(get_template_directory_uri()).'/assets/images/layout3.png'
  ))));

  //Blog Post
	$wp_customize->add_panel( $VWMaintenanceServicesParentPanel );

	$BlogPostParentPanel = new VW_Maintenance_Services_WP_Customize_Panel( $wp_customize, 'blog_post_parent_panel', array(
		'title' => __( 'Blog Post Settings', 'vw-maintenance-services' ),
		'panel' => 'vw_maintenance_services_panel_id',
	));

	$wp_customize->add_panel( $BlogPostParentPanel );

	// Add example section and controls to the middle (second) panel
	$wp_customize->add_section( 'vw_maintenance_services_post_settings', array(
		'title' => __( 'Post Settings', 'vw-maintenance-services' ),
		'panel' => 'blog_post_parent_panel',
	));

	//Blog Post layout
  $wp_customize->add_setting('vw_maintenance_services_blog_layout_option',array(
    'default' => 'Default',
    'sanitize_callback' => 'vw_maintenance_services_sanitize_choices'
  ));
  $wp_customize->add_control(new VW_Maintenance_Services_Image_Radio_Control($wp_customize, 'vw_maintenance_services_blog_layout_option', array(
      'type' => 'select',
      'label' => __('Blog Post Layouts','vw-maintenance-services'),
      'section' => 'vw_maintenance_services_post_settings',
      'choices' => array(
          'Default' => esc_url(get_template_directory_uri()).'/assets/images/blog-layout1.png',
          'Center' => esc_url(get_template_directory_uri()).'/assets/images/blog-layout2.png',
          'Left' => esc_url(get_template_directory_uri()).'/assets/images/blog-layout3.png',
  ))));

	// Add Settings and Controls for Layout
	$wp_customize->add_setting('vw_maintenance_services_theme_options',array(
    'default' => 'Right Sidebar',
    'sanitize_callback' => 'vw_maintenance_services_sanitize_choices'	        
	) );
	$wp_customize->add_control('vw_maintenance_services_theme_options', array(
    'type' => 'select',
    'label' => __('Post Sidebar Layout','vw-maintenance-services'),
    'description' => __('Here you can change the sidebar layout for posts. ','vw-maintenance-services'),
    'section' => 'vw_maintenance_services_post_settings',
    'choices' => array(
        'Left Sidebar' => __('Left Sidebar','vw-maintenance-services'),
        'Right Sidebar' => __('Right Sidebar','vw-maintenance-services'),
        'One Column' => __('One Column','vw-maintenance-services'),
        'Three Columns' => __('Three Columns','vw-maintenance-services'),
        'Four Columns' => __('Four Columns','vw-maintenance-services'),
        'Grid Layout' => __('Grid Layout','vw-maintenance-services')
    ),
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('vw_maintenance_services_toggle_postdate', array( 
		'selector' => '.post-main-box h2 a', 
		'render_callback' => 'vw_maintenance_services_customize_partial_vw_maintenance_services_toggle_postdate', 
	));

	$wp_customize->add_setting('vw_maintenance_services_toggle_postdate_icon',array(
		'default'	=> 'fa fa-calendar',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new VW_Maintenance_Services_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_maintenance_services_toggle_postdate_icon',array(
		'label'	=> __('Add Post Date Icon','vw-maintenance-services'),
		'transport' => 'refresh',
		'section'	=> 'vw_maintenance_services_post_settings',
		'setting'	=> 'vw_maintenance_services_toggle_postdate_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting( 'vw_maintenance_services_toggle_postdate',array(
    'default' => 1,
    'transport' => 'refresh',
    'sanitize_callback' => 'vw_maintenance_services_switch_sanitization'
  ) );
  $wp_customize->add_control( new VW_Maintenance_Services_Toggle_Switch_Custom_Control( $wp_customize, 'vw_maintenance_services_toggle_postdate',array(
      'label' => esc_html__( 'Show / Hide Post Date','vw-maintenance-services' ),
      'section' => 'vw_maintenance_services_post_settings'
  )));

  $wp_customize->add_setting('vw_maintenance_services_toggle_author_icon',array(
		'default'	=> 'fas fa-user',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new VW_Maintenance_Services_Fontawesome_Icon_Chooser(
  $wp_customize,'vw_maintenance_services_toggle_author_icon',array(
		'label'	=> __('Add Author Icon','vw-maintenance-services'),
		'transport' => 'refresh',
		'section'	=> 'vw_maintenance_services_post_settings',
		'setting'	=> 'vw_maintenance_services_toggle_author_icon',
		'type'		=> 'icon'
	)));

  $wp_customize->add_setting( 'vw_maintenance_services_toggle_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_maintenance_services_switch_sanitization'
  ) );
	$wp_customize->add_control( new VW_Maintenance_Services_Toggle_Switch_Custom_Control( $wp_customize, 'vw_maintenance_services_toggle_author',array(
		'label' => esc_html__( 'Show / Hide Author','vw-maintenance-services' ),
		'section' => 'vw_maintenance_services_post_settings'
  )));

  $wp_customize->add_setting('vw_maintenance_services_toggle_comments_icon',array(
		'default'	=> 'fa fa-comments',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new VW_Maintenance_Services_Fontawesome_Icon_Chooser(
  $wp_customize,'vw_maintenance_services_toggle_comments_icon',array(
		'label'	=> __('Add Comments Icon','vw-maintenance-services'),
		'transport' => 'refresh',
		'section'	=> 'vw_maintenance_services_post_settings',
		'setting'	=> 'vw_maintenance_services_toggle_comments_icon',
		'type'		=> 'icon'
	)));

  $wp_customize->add_setting( 'vw_maintenance_services_toggle_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_maintenance_services_switch_sanitization'
  ) );
  $wp_customize->add_control( new VW_Maintenance_Services_Toggle_Switch_Custom_Control( $wp_customize, 'vw_maintenance_services_toggle_comments',array(
		'label' => esc_html__( 'Show / Hide Comments','vw-maintenance-services' ),
		'section' => 'vw_maintenance_services_post_settings'
  )));

  $wp_customize->add_setting('vw_maintenance_services_toggle_time_icon',array(
		'default'	=> 'far fa-clock',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new VW_Maintenance_Services_Fontawesome_Icon_Chooser(
  $wp_customize,'vw_maintenance_services_toggle_time_icon',array(
		'label'	=> __('Add Time Icon','vw-maintenance-services'),
		'transport' => 'refresh',
		'section'	=> 'vw_maintenance_services_post_settings',
		'setting'	=> 'vw_maintenance_services_toggle_time_icon',
		'type'		=> 'icon'
	)));

  $wp_customize->add_setting( 'vw_maintenance_services_toggle_time',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_maintenance_services_switch_sanitization'
  ) );
  $wp_customize->add_control( new VW_Maintenance_Services_Toggle_Switch_Custom_Control( $wp_customize, 'vw_maintenance_services_toggle_time',array(
		'label' => esc_html__( 'Show / Hide Time','vw-maintenance-services' ),
		'section' => 'vw_maintenance_services_post_settings'
  )));

  $wp_customize->add_setting( 'vw_maintenance_services_featured_image_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_maintenance_services_switch_sanitization'
	));
  $wp_customize->add_control( new VW_Maintenance_Services_Toggle_Switch_Custom_Control( $wp_customize, 'vw_maintenance_services_featured_image_hide_show', array(
		'label' => esc_html__( 'Show / Hide Featured Image','vw-maintenance-services' ),
		'section' => 'vw_maintenance_services_post_settings'
  )));

  $wp_customize->add_setting( 'vw_maintenance_services_featured_image_border_radius', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_maintenance_services_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_maintenance_services_featured_image_border_radius', array(
		'label'       => esc_html__( 'Featured Image Border Radius','vw-maintenance-services' ),
		'section'     => 'vw_maintenance_services_post_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting( 'vw_maintenance_services_featured_image_box_shadow', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_maintenance_services_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_maintenance_services_featured_image_box_shadow', array(
		'label'       => esc_html__( 'Featured Image Box Shadow','vw-maintenance-services' ),
		'section'     => 'vw_maintenance_services_post_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	//Featured Image
	$wp_customize->add_setting('vw_maintenance_services_blog_post_featured_image_dimension',array(
		'default' => 'default',
		'sanitize_callback'	=> 'vw_maintenance_services_sanitize_choices'
	));
	$wp_customize->add_control('vw_maintenance_services_blog_post_featured_image_dimension',array(
		'type' => 'select',
		'label'	=> __('Blog Post Featured Image Dimension','vw-maintenance-services'),
		'section'	=> 'vw_maintenance_services_post_settings',
		'choices' => array(
		  	'default' => __('Default','vw-maintenance-services'),
  			'custom' => __('Custom Image Size','vw-maintenance-services'),
    ),
	));

	$wp_customize->add_setting('vw_maintenance_services_blog_post_featured_image_custom_width',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
		));
	$wp_customize->add_control('vw_maintenance_services_blog_post_featured_image_custom_width',array(
		'label'	=> __('Featured Image Custom Width','vw-maintenance-services'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-maintenance-services'),
		'input_attrs' => array(
    'placeholder' => __( '10px', 'vw-maintenance-services' ),),
		'section'=> 'vw_maintenance_services_post_settings',
		'type'=> 'text',
		'active_callback' => 'vw_maintenance_services_blog_post_featured_image_dimension'
		));

	$wp_customize->add_setting('vw_maintenance_services_blog_post_featured_image_custom_height',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_blog_post_featured_image_custom_height',array(
		'label'	=> __('Featured Image Custom Height','vw-maintenance-services'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-maintenance-services'),
		'input_attrs' => array(
    'placeholder' => __( '10px', 'vw-maintenance-services' ),),
		'section'=> 'vw_maintenance_services_post_settings',
		'type'=> 'text',
		'active_callback' => 'vw_maintenance_services_blog_post_featured_image_dimension'
	));

  $wp_customize->add_setting( 'vw_maintenance_services_excerpt_number', array(
		'default'              => 30,
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_maintenance_services_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_maintenance_services_excerpt_number', array(
		'label'       => esc_html__( 'Excerpt length','vw-maintenance-services' ),
		'section'     => 'vw_maintenance_services_post_settings',
		'type'        => 'range',
		'settings'    => 'vw_maintenance_services_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting('vw_maintenance_services_meta_field_separator',array(
		'default'=> '|',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_meta_field_separator',array(
		'label'	=> __('Add Meta Separator','vw-maintenance-services'),
		'description' => __('Add the seperator for meta box. Example: "|", "/", etc.','vw-maintenance-services'),
		'section'=> 'vw_maintenance_services_post_settings',
		'type'=> 'text'
	));

  $wp_customize->add_setting('vw_maintenance_services_excerpt_settings',array(
    'default' => 'Excerpt',
    'transport' => 'refresh',
    'sanitize_callback' => 'vw_maintenance_services_sanitize_choices'
	));
	$wp_customize->add_control('vw_maintenance_services_excerpt_settings',array(
    'type' => 'select',
    'label' => __('Post Content','vw-maintenance-services'),
    'section' => 'vw_maintenance_services_post_settings',
    'choices' => array(
    		'Content' => __('Content','vw-maintenance-services'),
        'Excerpt' => __('Excerpt','vw-maintenance-services'),
        'No Content' => __('No Content','vw-maintenance-services')
        ),
	) );

	$wp_customize->add_setting('vw_maintenance_services_excerpt_suffix',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_excerpt_suffix',array(
		'label'	=> __('Add Excerpt Suffix','vw-maintenance-services'),
		'input_attrs' => array(
    'placeholder' => __( '[...]', 'vw-maintenance-services' ),
        ),
		'section'=> 'vw_maintenance_services_post_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'vw_maintenance_services_blog_pagination_hide_show',array(
    'default' => 1,
    'transport' => 'refresh',
    'sanitize_callback' => 'vw_maintenance_services_switch_sanitization'
  ));  
  $wp_customize->add_control( new VW_Maintenance_Services_Toggle_Switch_Custom_Control( $wp_customize, 'vw_maintenance_services_blog_pagination_hide_show',array(
      'label' => esc_html__( 'Show / Hide Blog Pagination','vw-maintenance-services' ),
      'section' => 'vw_maintenance_services_post_settings'
  )));

	$wp_customize->add_setting( 'vw_maintenance_services_blog_pagination_type', array(
    'default'			=> 'blog-page-numbers',
    'sanitize_callback'	=> 'vw_maintenance_services_sanitize_choices'
	));
	$wp_customize->add_control( 'vw_maintenance_services_blog_pagination_type', array(
    'section' => 'vw_maintenance_services_post_settings',
    'type' => 'select',
    'label' => __( 'Blog Pagination', 'vw-maintenance-services' ),
    'choices'		=> array(
        'blog-page-numbers'  => __( 'Numeric', 'vw-maintenance-services' ),
        'next-prev' => __( 'Older Posts/Newer Posts', 'vw-maintenance-services' ),
  )));

 $wp_customize->add_setting('vw_maintenance_services_blog_page_posts_settings',array(
    'default' => 'Into Blocks',
    'transport' => 'refresh',
    'sanitize_callback' => 'vw_maintenance_services_sanitize_choices'
	));
	$wp_customize->add_control('vw_maintenance_services_blog_page_posts_settings',array(
    'type' => 'select',
    'label' => __('Display Blog posts','vw-maintenance-services'),
    'section' => 'vw_maintenance_services_post_settings',
    'choices' => array(
    		'Into Blocks' => __('Into Blocks','vw-maintenance-services'),
        'Without Blocks' => __('Without Blocks','vw-maintenance-services')
        ),
	) );

  // Button Settings
	$wp_customize->add_section( 'vw_maintenance_services_button_settings', array(
		'title' => __( 'Button Settings', 'vw-maintenance-services' ),
		'panel' => 'blog_post_parent_panel',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('vw_maintenance_services_button_text', array( 
		'selector' => '.post-main-box .content-bttn a', 
		'render_callback' => 'vw_maintenance_services_customize_partial_vw_maintenance_services_button_text', 
	));

	$wp_customize->add_setting('vw_maintenance_services_button_text',array(
		'default'=> esc_html__( 'Read More', 'vw-maintenance-services' ),
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_button_text',array(
		'label'	=> __('Add Button Text','vw-maintenance-services'),
		'input_attrs' => array(
    'placeholder' => __( 'Read More', 'vw-maintenance-services' ),
        ),
		'section'=> 'vw_maintenance_services_button_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_maintenance_services_blog_button_icon',array(
		'default'	=> 'fa fa-angle-right',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new VW_Maintenance_Services_Fontawesome_Icon_Chooser(
  $wp_customize,'vw_maintenance_services_blog_button_icon',array(
		'label'	=> __('Add Button Icon','vw-maintenance-services'),
		'transport' => 'refresh',
		'section'	=> 'vw_maintenance_services_button_settings',
		'setting'	=> 'vw_maintenance_services_blog_button_icon',
		'type'		=> 'icon'
	)));

	// font size button
	$wp_customize->add_setting('vw_maintenance_services_button_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_button_font_size',array(
		'label'	=> __('Button Font Size','vw-maintenance-services'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-maintenance-services'),
		'input_attrs' => array(
  	'placeholder' => __( '10px', 'vw-maintenance-services' ),
    ),
  	'type'        => 'text',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
		'section'=> 'vw_maintenance_services_button_settings',
	));

	$wp_customize->add_setting( 'vw_maintenance_services_button_border_radius', array(
		'default'              => '',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_maintenance_services_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_maintenance_services_button_border_radius', array(
		'label'       => esc_html__( 'Button Border Radius','vw-maintenance-services' ),
		'section'     => 'vw_maintenance_services_button_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting('vw_maintenance_services_button_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_button_padding_top_bottom',array(
		'label'	=> __('Padding Top Bottom','vw-maintenance-services'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-maintenance-services'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-maintenance-services' ),
        ),
		'section'=> 'vw_maintenance_services_button_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_maintenance_services_button_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_button_padding_left_right',array(
		'label'	=> __('Padding Left Right','vw-maintenance-services'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-maintenance-services'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-maintenance-services' ),
        ),
		'section'=> 'vw_maintenance_services_button_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_maintenance_services_button_letter_spacing',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_button_letter_spacing',array(
		'label'	=> __('Button Letter Spacing','vw-maintenance-services'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-maintenance-services'),
		'input_attrs' => array(
      	'placeholder' => __( '10px', 'vw-maintenance-services' ),
    ),
    'type'        => 'text',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
		'section'=> 'vw_maintenance_services_button_settings',
	));

	// text trasform
	$wp_customize->add_setting('vw_maintenance_services_button_text_transform',array(
		'default'=> 'Uppercase',
		'sanitize_callback'	=> 'vw_maintenance_services_sanitize_choices'
	));
	$wp_customize->add_control('vw_maintenance_services_button_text_transform',array(
		'type' => 'radio',
		'label'	=> __('Button Text Transform','vw-maintenance-services'),
		'choices' => array(
      'Uppercase' => __('Uppercase','vw-maintenance-services'),
      'Capitalize' => __('Capitalize','vw-maintenance-services'),
      'Lowercase' => __('Lowercase','vw-maintenance-services'),
        ),
		'section'=> 'vw_maintenance_services_button_settings',
	));

	// Related Post Settings
	$wp_customize->add_section( 'vw_maintenance_services_related_posts_settings', array(
		'title' => __( 'Related Posts Settings', 'vw-maintenance-services' ),
		'panel' => 'blog_post_parent_panel',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('vw_maintenance_services_related_post_title', array( 
		'selector' => '.related-post h3', 
		'render_callback' => 'vw_maintenance_services_customize_partial_vw_maintenance_services_related_post_title', 
	));

  $wp_customize->add_setting( 'vw_maintenance_services_related_post',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_maintenance_services_switch_sanitization'
  ) );
  $wp_customize->add_control( new VW_Maintenance_Services_Toggle_Switch_Custom_Control( $wp_customize, 'vw_maintenance_services_related_post',array(
		'label' => esc_html__( 'Show / Hide Related Post','vw-maintenance-services' ),
		'section' => 'vw_maintenance_services_related_posts_settings'
  )));

  $wp_customize->add_setting('vw_maintenance_services_related_post_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_related_post_title',array(
		'label'	=> __('Add Related Post Title','vw-maintenance-services'),
		'input_attrs' => array(
            'placeholder' => __( 'Related Post', 'vw-maintenance-services' ),
        ),
		'section'=> 'vw_maintenance_services_related_posts_settings',
		'type'=> 'text'
	));

  $wp_customize->add_setting('vw_maintenance_services_related_posts_count',array(
		'default'=> '3',
		'sanitize_callback'	=> 'vw_maintenance_services_sanitize_float'
	));
	$wp_customize->add_control('vw_maintenance_services_related_posts_count',array(
		'label'	=> __('Add Related Post Count','vw-maintenance-services'),
		'input_attrs' => array(
            'placeholder' => __( '3', 'vw-maintenance-services' ),
        ),
		'section'=> 'vw_maintenance_services_related_posts_settings',
		'type'=> 'number'
	));

	$wp_customize->add_setting( 'vw_maintenance_services_related_posts_excerpt_number', array(
		'default'              => 20,
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_maintenance_services_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_maintenance_services_related_posts_excerpt_number', array(
		'label'       => esc_html__( 'Related Posts Excerpt length','vw-maintenance-services' ),
		'section'     => 'vw_maintenance_services_related_posts_settings',
		'type'        => 'range',
		'settings'    => 'vw_maintenance_services_related_posts_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	// Single Posts Settings
	$wp_customize->add_section( 'vw_maintenance_services_single_blog_settings', array(
		'title' => __( 'Single Post Settings', 'vw-maintenance-services' ),
		'panel' => 'blog_post_parent_panel',
	));

	$wp_customize->add_setting('vw_maintenance_services_single_postdate_icon',array(
		'default'	=> 'fas fa-calendar-alt',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new VW_Maintenance_Services_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_maintenance_services_single_postdate_icon',array(
		'label'	=> __('Add Post Date Icon','vw-maintenance-services'),
		'transport' => 'refresh',
		'section'	=> 'vw_maintenance_services_single_blog_settings',
		'setting'	=> 'vw_maintenance_services_single_postdate_icon',
		'type'		=> 'icon'
	)));

 	$wp_customize->add_setting( 'vw_maintenance_services_single_postdate',array(
    'default' => 1,
    'transport' => 'refresh',
    'sanitize_callback' => 'vw_maintenance_services_switch_sanitization'
	) );
	$wp_customize->add_control( new VW_Maintenance_Services_Toggle_Switch_Custom_Control( $wp_customize, 'vw_maintenance_services_single_postdate',array(
	  'label' => esc_html__( 'Show / Hide Date','vw-maintenance-services' ),
	  'section' => 'vw_maintenance_services_single_blog_settings'
	)));

	$wp_customize->add_setting('vw_maintenance_services_single_author_icon',array(
		'default'	=> 'far fa-user',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new VW_Maintenance_Services_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_maintenance_services_single_author_icon',array(
		'label'	=> __('Add Author Icon','vw-maintenance-services'),
		'transport' => 'refresh',
		'section'	=> 'vw_maintenance_services_single_blog_settings',
		'setting'	=> 'vw_maintenance_services_single_author_icon',
		'type'		=> 'icon'
	)));

  $wp_customize->add_setting( 'vw_maintenance_services_single_author',array(
    'default' => 1,
    'transport' => 'refresh',
    'sanitize_callback' => 'vw_maintenance_services_switch_sanitization'
	) );
	$wp_customize->add_control( new VW_Maintenance_Services_Toggle_Switch_Custom_Control( $wp_customize, 'vw_maintenance_services_single_author',array(
    'label' => esc_html__( 'Show / Hide Author','vw-maintenance-services' ),
    'section' => 'vw_maintenance_services_single_blog_settings'
	)));

 	$wp_customize->add_setting('vw_maintenance_services_single_comments_icon',array(
		'default'	=> 'fa fa-comments',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new VW_Maintenance_Services_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_maintenance_services_single_comments_icon',array(
		'label'	=> __('Add Comments Icon','vw-maintenance-services'),
		'transport' => 'refresh',
		'section'	=> 'vw_maintenance_services_single_blog_settings',
		'setting'	=> 'vw_maintenance_services_single_comments_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting( 'vw_maintenance_services_single_comments',array(
    'default' => 1,
    'transport' => 'refresh',
    'sanitize_callback' => 'vw_maintenance_services_switch_sanitization'
	) );
	$wp_customize->add_control( new VW_Maintenance_Services_Toggle_Switch_Custom_Control( $wp_customize, 'vw_maintenance_services_single_comments',array(
    'label' => esc_html__( 'Show / Hide Comments','vw-maintenance-services' ),
    'section' => 'vw_maintenance_services_single_blog_settings'
	)));

	$wp_customize->add_setting('vw_maintenance_services_single_time_icon',array(
		'default'	=> 'far fa-clock',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new VW_Maintenance_Services_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_maintenance_services_single_time_icon',array(
		'label'	=> __('Add Time Icon','vw-maintenance-services'),
		'transport' => 'refresh',
		'section'	=> 'vw_maintenance_services_single_blog_settings',
		'setting'	=> 'vw_maintenance_services_single_time_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting( 'vw_maintenance_services_single_time',array(
    'default' => 1,
    'transport' => 'refresh',
    'sanitize_callback' => 'vw_maintenance_services_switch_sanitization'
	) );
	$wp_customize->add_control( new VW_Maintenance_Services_Toggle_Switch_Custom_Control( $wp_customize, 'vw_maintenance_services_single_time',array(
    'label' => esc_html__( 'Show / Hide Time','vw-maintenance-services' ),
    'section' => 'vw_maintenance_services_single_blog_settings'
	)));

	$wp_customize->add_setting( 'vw_maintenance_services_single_post_breadcrumb',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_maintenance_services_switch_sanitization'
  ) );
  $wp_customize->add_control( new VW_Maintenance_Services_Toggle_Switch_Custom_Control( $wp_customize, 'vw_maintenance_services_single_post_breadcrumb',array(
		'label' => esc_html__( 'Show / Hide Post Breadcrumb','vw-maintenance-services' ),
		'section' => 'vw_maintenance_services_single_blog_settings'
  )));

  // Single Posts Category
  $wp_customize->add_setting( 'vw_maintenance_services_single_post_category',array(
		'default' => true,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_maintenance_services_switch_sanitization'
  ) );
	$wp_customize->add_control( new VW_Maintenance_Services_Toggle_Switch_Custom_Control( $wp_customize, 'vw_maintenance_services_single_post_category',array(
		'label' => esc_html__( 'Show / Hide Post Category','vw-maintenance-services' ),
		'section' => 'vw_maintenance_services_single_blog_settings'
    )));

	$wp_customize->add_setting( 'vw_maintenance_services_toggle_tags',array(
		'default' => 0,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_maintenance_services_switch_sanitization'
	));
  $wp_customize->add_control( new VW_Maintenance_Services_Toggle_Switch_Custom_Control( $wp_customize, 'vw_maintenance_services_toggle_tags', array(
		'label' => esc_html__( 'Show / Hide Tags','vw-maintenance-services' ),
		'section' => 'vw_maintenance_services_single_blog_settings'
  )));

	$wp_customize->add_setting( 'vw_maintenance_services_single_blog_post_navigation_show_hide',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_maintenance_services_switch_sanitization'
	));
  $wp_customize->add_control( new VW_Maintenance_Services_Toggle_Switch_Custom_Control( $wp_customize, 'vw_maintenance_services_single_blog_post_navigation_show_hide', array(
		'label' => esc_html__( 'Show / Hide Post Navigation','vw-maintenance-services' ),
		'section' => 'vw_maintenance_services_single_blog_settings'
    )));

	$wp_customize->add_setting('vw_maintenance_services_single_post_meta_field_separator',array(
		'default'=> '|',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_single_post_meta_field_separator',array(
		'label'	=> __('Add Meta Separator','vw-maintenance-services'),
		'description' => __('Add the seperator for meta box. Example: "|", "/", etc.','vw-maintenance-services'),
		'section'=> 'vw_maintenance_services_single_blog_settings',
		'type'=> 'text'
	));

	//navigation text
	$wp_customize->add_setting('vw_maintenance_services_single_blog_prev_navigation_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_single_blog_prev_navigation_text',array(
		'label'	=> __('Post Navigation Text','vw-maintenance-services'),
		'input_attrs' => array(
            'placeholder' => __( 'PREVIOUS', 'vw-maintenance-services' ),
        ),
		'section'=> 'vw_maintenance_services_single_blog_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_maintenance_services_single_blog_next_navigation_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_single_blog_next_navigation_text',array(
		'label'	=> __('Post Navigation Text','vw-maintenance-services'),
		'input_attrs' => array(
            'placeholder' => __( 'NEXT', 'vw-maintenance-services' ),
        ),
		'section'=> 'vw_maintenance_services_single_blog_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_maintenance_services_single_blog_comment_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('vw_maintenance_services_single_blog_comment_title',array(
		'label'	=> __('Add Comment Title','vw-maintenance-services'),
		'input_attrs' => array(
    'placeholder' => __( 'Leave a Reply', 'vw-maintenance-services' ),
        ),
		'section'=> 'vw_maintenance_services_single_blog_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_maintenance_services_single_blog_comment_button_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('vw_maintenance_services_single_blog_comment_button_text',array(
		'label'	=> __('Add Comment Button Text','vw-maintenance-services'),
		'input_attrs' => array(
            'placeholder' => __( 'Post Comment', 'vw-maintenance-services' ),
        ),
		'section'=> 'vw_maintenance_services_single_blog_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_maintenance_services_single_blog_comment_width',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_single_blog_comment_width',array(
		'label'	=> __('Comment Form Width','vw-maintenance-services'),
		'description'	=> __('Enter a value in %. Example:50%','vw-maintenance-services'),
		'input_attrs' => array(
            'placeholder' => __( '100%', 'vw-maintenance-services' ),
        ),
		'section'=> 'vw_maintenance_services_single_blog_settings',
		'type'=> 'text'
	));

	 // Grid layout setting
	$wp_customize->add_section( 'vw_maintenance_services_grid_layout_settings', array(
		'title' => __( 'Grid Layout Settings', 'vw-maintenance-services' ),
		'panel' => 'blog_post_parent_panel',
	));

	$wp_customize->add_setting('vw_maintenance_services_grid_postdate_icon',array(
		'default'	=> 'fas fa-calendar-alt',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new VW_Maintenance_Services_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_maintenance_services_grid_postdate_icon',array(
		'label'	=> __('Add Post Date Icon','vw-maintenance-services'),
		'transport' => 'refresh',
		'section'	=> 'vw_maintenance_services_grid_layout_settings',
		'setting'	=> 'vw_maintenance_services_grid_postdate_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting( 'vw_maintenance_services_grid_postdate',array(
    'default' => 1,
    'transport' => 'refresh',
    'sanitize_callback' => 'vw_maintenance_services_switch_sanitization'
  ) );
  $wp_customize->add_control( new VW_Maintenance_Services_Toggle_Switch_Custom_Control( $wp_customize, 'vw_maintenance_services_grid_postdate',array(
    'label' => esc_html__( 'Show / Hide Post Date','vw-maintenance-services' ),
    'section' => 'vw_maintenance_services_grid_layout_settings'
  )));

	$wp_customize->add_setting('vw_maintenance_services_grid_author_icon',array(
		'default'	=> 'far fa-user',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new VW_Maintenance_Services_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_maintenance_services_grid_author_icon',array(
		'label'	=> __('Add Author Icon','vw-maintenance-services'),
		'transport' => 'refresh',
		'section'	=> 'vw_maintenance_services_grid_layout_settings',
		'setting'	=> 'vw_maintenance_services_grid_author_icon',
		'type'		=> 'icon'
	)));

  $wp_customize->add_setting( 'vw_maintenance_services_grid_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_maintenance_services_switch_sanitization'
  ) );
  $wp_customize->add_control( new VW_Maintenance_Services_Toggle_Switch_Custom_Control( $wp_customize, 'vw_maintenance_services_grid_author',array(
		'label' => esc_html__( 'Show / Hide Author','vw-maintenance-services' ),
		'section' => 'vw_maintenance_services_grid_layout_settings'
  )));

	$wp_customize->add_setting('vw_maintenance_services_grid_comments_icon',array(
		'default'	=> 'fa fa-comments',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new VW_Maintenance_Services_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_maintenance_services_grid_comments_icon',array(
		'label'	=> __('Add Comments Icon','vw-maintenance-services'),
		'transport' => 'refresh',
		'section'	=> 'vw_maintenance_services_grid_layout_settings',
		'setting'	=> 'vw_maintenance_services_grid_comments_icon',
		'type'		=> 'icon'
	)));

  $wp_customize->add_setting( 'vw_maintenance_services_grid_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_maintenance_services_switch_sanitization'
  ) );
  $wp_customize->add_control( new VW_Maintenance_Services_Toggle_Switch_Custom_Control( $wp_customize, 'vw_maintenance_services_grid_comments',array(
		'label' => esc_html__( 'Show / Hide Comments','vw-maintenance-services' ),
		'section' => 'vw_maintenance_services_grid_layout_settings'
  )));

  $wp_customize->add_setting('vw_maintenance_services_grid_post_meta_field_separator',array(
		'default'=> '|',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_grid_post_meta_field_separator',array(
		'label'	=> __('Add Meta Separator','vw-maintenance-services'),
		'description' => __('Add the seperator for meta box. Example: "|", "/", etc.','vw-maintenance-services'),
		'section'=> 'vw_maintenance_services_grid_layout_settings',
		'type'=> 'text'
	));  

  $wp_customize->add_setting('vw_maintenance_services_display_grid_posts_settings',array(
    'default' => 'Into Blocks',
    'transport' => 'refresh',
    'sanitize_callback' => 'vw_maintenance_services_sanitize_choices'
	));
	$wp_customize->add_control('vw_maintenance_services_display_grid_posts_settings',array(
    'type' => 'select',
    'label' => __('Display Grid Posts','vw-maintenance-services'),
    'section' => 'vw_maintenance_services_grid_layout_settings',
    'choices' => array(
    	'Into Blocks' => __('Into Blocks','vw-maintenance-services'),
      'Without Blocks' => __('Without Blocks','vw-maintenance-services')
      ),
	) );

	$wp_customize->add_setting('vw_maintenance_services_grid_button_text',array(
		'default'=> esc_html__('Read More','vw-maintenance-services'),
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_grid_button_text',array(
		'label'	=> esc_html__('Add Button Text','vw-maintenance-services'),
		'input_attrs' => array(
        'placeholder' => esc_html__( 'Read More', 'vw-maintenance-services' ),
      ),
		'section'=> 'vw_maintenance_services_grid_layout_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_maintenance_services_grid_button_icon',array(
		'default'	=> 'fa fa-angle-right',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new VW_Maintenance_Services_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_maintenance_services_grid_button_icon',array(
		'label'	=> __('Add Comments Icon','vw-maintenance-services'),
		'transport' => 'refresh',
		'section'	=> 'vw_maintenance_services_grid_layout_settings',
		'setting'	=> 'vw_maintenance_services_grid_button_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('vw_maintenance_services_grid_excerpt_suffix',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_grid_excerpt_suffix',array(
		'label'	=> __('Add Excerpt Suffix','vw-maintenance-services'),
		'input_attrs' => array(
            'placeholder' => __( '[...]', 'vw-maintenance-services' ),
        ),
		'section'=> 'vw_maintenance_services_grid_layout_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_maintenance_services_grid_excerpt_settings',array(
        'default' => 'Excerpt',
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_maintenance_services_sanitize_choices'
	));
	$wp_customize->add_control('vw_maintenance_services_grid_excerpt_settings',array(
        'type' => 'select',
        'label' => esc_html__('Grid Post Content','vw-maintenance-services'),
        'section' => 'vw_maintenance_services_grid_layout_settings',
        'choices' => array(
        	'Content' => esc_html__('Content','vw-maintenance-services'),
            'Excerpt' => esc_html__('Excerpt','vw-maintenance-services'),
            'No Content' => esc_html__('No Content','vw-maintenance-services')
        ),
	) );

 	// other settings
	$OtherParentPanel = new VW_Maintenance_Services_WP_Customize_Panel( $wp_customize, 'vw_maintenance_services_other_panel_id', array(
		'title' => __( 'Others Settings', 'vw-maintenance-services' ),
		'panel' => 'vw_maintenance_services_panel_id',
	));

	$wp_customize->add_panel( $OtherParentPanel );

	// Layout
	$wp_customize->add_section( 'vw_maintenance_services_left_right', array(
  	'title'      => esc_html__( 'General Settings', 'vw-maintenance-services' ),
		'panel' => 'vw_maintenance_services_other_panel_id'
	) );

	$wp_customize->add_setting('vw_maintenance_services_width_option',array(
    'default' => 'Full Width',
    'sanitize_callback' => 'vw_maintenance_services_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Maintenance_Services_Image_Radio_Control($wp_customize, 'vw_maintenance_services_width_option', array(
    'type' => 'select',
    'label' => __('Width Layouts','vw-maintenance-services'),
    'description' => __('Here you can change the width layout of Website.','vw-maintenance-services'),
    'section' => 'vw_maintenance_services_left_right',
    'choices' => array(
        'Full Width' => esc_url(get_template_directory_uri()).'/assets/images/full-width.png',
        'Wide Width' => esc_url(get_template_directory_uri()).'/assets/images/wide-width.png',
        'Boxed' => esc_url(get_template_directory_uri()).'/assets/images/boxed-width.png',
  ))));

	$wp_customize->add_setting('vw_maintenance_services_page_layout',array(
    'default' => 'One Column',
    'sanitize_callback' => 'vw_maintenance_services_sanitize_choices'
	));
	$wp_customize->add_control('vw_maintenance_services_page_layout',array(
    'type' => 'select',
    'label' => __('Page Sidebar Layout','vw-maintenance-services'),
    'description' => __('Here you can change the sidebar layout for pages. ','vw-maintenance-services'),
    'section' => 'vw_maintenance_services_left_right',
    'choices' => array(
        'Left Sidebar' => __('Left Sidebar','vw-maintenance-services'),
        'Right Sidebar' => __('Right Sidebar','vw-maintenance-services'),
        'One Column' => __('One Column','vw-maintenance-services')
        ),
	) );

	$wp_customize->add_setting( 'vw_maintenance_services_single_page_breadcrumb',array(
		'default' => 0,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_maintenance_services_switch_sanitization'
  ) );
  $wp_customize->add_control( new VW_Maintenance_Services_Toggle_Switch_Custom_Control( $wp_customize, 'vw_maintenance_services_single_page_breadcrumb',array(
		'label' => esc_html__( 'Show / Hide Page Breadcrumb','vw-maintenance-services' ),
		'section' => 'vw_maintenance_services_left_right'
  )));

 	//Wow Animation
	$wp_customize->add_setting( 'vw_maintenance_services_animation',array(
    'default' => 1,
    'transport' => 'refresh',
    'sanitize_callback' => 'vw_maintenance_services_switch_sanitization'
  ));
  $wp_customize->add_control( new VW_Maintenance_Services_Toggle_Switch_Custom_Control( $wp_customize, 'vw_maintenance_services_animation',array(
      'label' => esc_html__( 'Show / Hide Animation ','vw-maintenance-services' ),
      'description' => __('Here you can disable overall site animation effect','vw-maintenance-services'),
      'section' => 'vw_maintenance_services_left_right'
  )));

	//Pre-Loader
	$wp_customize->add_setting( 'vw_maintenance_services_loader_enable',array(
    'default' => 0,
    'transport' => 'refresh',
    'sanitize_callback' => 'vw_maintenance_services_switch_sanitization'
  ) );
  $wp_customize->add_control( new VW_Maintenance_Services_Toggle_Switch_Custom_Control( $wp_customize, 'vw_maintenance_services_loader_enable',array(
    'label' => esc_html__( 'Show / Hide Pre-Loader','vw-maintenance-services' ),
    'section' => 'vw_maintenance_services_left_right'
  )));

	$wp_customize->add_setting('vw_maintenance_services_preloader_bg_color', array(
		'default'           => '#fb7f7f',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'vw_maintenance_services_preloader_bg_color', array(
		'label'    => __('Pre-Loader Background Color', 'vw-maintenance-services'),
		'section'  => 'vw_maintenance_services_left_right',
	)));

	$wp_customize->add_setting('vw_maintenance_services_preloader_border_color', array(
		'default'           => '#ffffff',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'vw_maintenance_services_preloader_border_color', array(
		'label'    => __('Pre-Loader Border Color', 'vw-maintenance-services'),
		'section'  => 'vw_maintenance_services_left_right',
	)));

	$wp_customize->add_setting('vw_maintenance_services_preloader_bg_img',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw',
	));
	$wp_customize->add_control( new WP_Customize_Image_Control($wp_customize,'vw_maintenance_services_preloader_bg_img',array(
    'label' => __('Preloader Background Image','vw-maintenance-services'),
    'section' => 'vw_maintenance_services_left_right'
	)));

  //404 Page Setting
	$wp_customize->add_section('vw_maintenance_services_404_page',array(
		'title'	=> __('404 Page Settings','vw-maintenance-services'),
		'panel' => 'vw_maintenance_services_other_panel_id',
	));	

	$wp_customize->add_setting('vw_maintenance_services_404_page_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('vw_maintenance_services_404_page_title',array(
		'label'	=> __('Add Title','vw-maintenance-services'),
		'input_attrs' => array(
    'placeholder' => __( '404 Not Found', 'vw-maintenance-services' ),
        ),
		'section'=> 'vw_maintenance_services_404_page',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_maintenance_services_404_page_content',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('vw_maintenance_services_404_page_content',array(
		'label'	=> __('Add Text','vw-maintenance-services'),
		'input_attrs' => array(
    'placeholder' => __( 'Looks like you have taken a wrong turn, Dont worry, it happens to the best of us.', 'vw-maintenance-services' ),
        ),
		'section'=> 'vw_maintenance_services_404_page',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_maintenance_services_404_page_button_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_404_page_button_text',array(
		'label'	=> __('Add Button Text','vw-maintenance-services'),
		'input_attrs' => array(
    'placeholder' => __( 'Return to the home page', 'vw-maintenance-services' ),
        ),
		'section'=> 'vw_maintenance_services_404_page',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_maintenance_services_404_page_button_icon',array(
		'default'	=> 'fa fa-angle-right',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new VW_Maintenance_Services_Fontawesome_Icon_Chooser(
  $wp_customize,'vw_maintenance_services_404_page_button_icon',array(
		'label'	=> __('Add Button Icon','vw-maintenance-services'),
		'transport' => 'refresh',
		'section'	=> 'vw_maintenance_services_404_page',
		'setting'	=> 'vw_maintenance_services_404_page_button_icon',
		'type'		=> 'icon'
	)));

	//No Result Page Setting
	$wp_customize->add_section('vw_maintenance_services_no_results_page',array(
		'title'	=> __('No Results Page Settings','vw-maintenance-services'),
		'panel' => 'vw_maintenance_services_other_panel_id',
	));	

	$wp_customize->add_setting('vw_maintenance_services_no_results_page_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('vw_maintenance_services_no_results_page_title',array(
		'label'	=> __('Add Title','vw-maintenance-services'),
		'input_attrs' => array(
    'placeholder' => __( 'Nothing Found', 'vw-maintenance-services' ),
        ),
		'section'=> 'vw_maintenance_services_no_results_page',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_maintenance_services_no_results_page_content',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('vw_maintenance_services_no_results_page_content',array(
		'label'	=> __('Add Text','vw-maintenance-services'),
		'input_attrs' => array(
    'placeholder' => __( 'Sorry, but nothing matched your search terms. Please try again with some different keywords.', 'vw-maintenance-services' ),
        ),
		'section'=> 'vw_maintenance_services_no_results_page',
		'type'=> 'text'
	));

	//Social Icon Setting
	$wp_customize->add_section('vw_maintenance_services_social_icon_settings',array(
		'title'	=> __('Social Icons Settings','vw-maintenance-services'),
		'panel' => 'vw_maintenance_services_other_panel_id',
	));	

	$wp_customize->add_setting('vw_maintenance_services_social_icon_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_social_icon_font_size',array(
		'label'	=> __('Icon Font Size','vw-maintenance-services'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-maintenance-services'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-maintenance-services' ),
        ),
		'section'=> 'vw_maintenance_services_social_icon_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_maintenance_services_social_icon_padding',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_social_icon_padding',array(
		'label'	=> __('Icon Padding','vw-maintenance-services'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-maintenance-services'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-maintenance-services' ),
        ),
		'section'=> 'vw_maintenance_services_social_icon_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_maintenance_services_social_icon_width',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_social_icon_width',array(
		'label'	=> __('Icon Width','vw-maintenance-services'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-maintenance-services'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-maintenance-services' ),
        ),
		'section'=> 'vw_maintenance_services_social_icon_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_maintenance_services_social_icon_height',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_social_icon_height',array(
		'label'	=> __('Icon Height','vw-maintenance-services'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-maintenance-services'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-maintenance-services' ),
        ),
		'section'=> 'vw_maintenance_services_social_icon_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'vw_maintenance_services_social_icon_border_radius', array(
		'default'              => '',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_maintenance_services_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_maintenance_services_social_icon_border_radius', array(
		'label'       => esc_html__( 'Icon Border Radius','vw-maintenance-services' ),
		'section'     => 'vw_maintenance_services_social_icon_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	//Responsive Media Settings
	$wp_customize->add_section('vw_maintenance_services_responsive_media',array(
		'title'	=> __('Responsive Media','vw-maintenance-services'),
		'panel' => 'vw_maintenance_services_other_panel_id',
	));

  $wp_customize->add_setting( 'vw_maintenance_services_stickyheader_hide_show',array(
  	'default' => 0,
  	'transport' => 'refresh',
  	'sanitize_callback' => 'vw_maintenance_services_switch_sanitization'
  ));  
  $wp_customize->add_control( new VW_Maintenance_Services_Toggle_Switch_Custom_Control( $wp_customize, 'vw_maintenance_services_stickyheader_hide_show',array(
    'label' => esc_html__( 'Sticky Header','vw-maintenance-services' ),
    'section' => 'vw_maintenance_services_responsive_media'
  )));

  $wp_customize->add_setting( 'vw_maintenance_services_resp_slider_hide_show',array(
    'default' => 1,
    'transport' => 'refresh',
    'sanitize_callback' => 'vw_maintenance_services_switch_sanitization'
  ));  
  $wp_customize->add_control( new VW_Maintenance_Services_Toggle_Switch_Custom_Control( $wp_customize, 'vw_maintenance_services_resp_slider_hide_show',array(
	    'label' => esc_html__( 'Show / Hide Slider','vw-maintenance-services' ),
	    'section' => 'vw_maintenance_services_responsive_media'
  )));

  $wp_customize->add_setting( 'vw_maintenance_services_sidebar_hide_show',array(
    'default' => 1,
    'transport' => 'refresh',
    'sanitize_callback' => 'vw_maintenance_services_switch_sanitization'
  ));  
  $wp_customize->add_control( new VW_Maintenance_Services_Toggle_Switch_Custom_Control( $wp_customize, 'vw_maintenance_services_sidebar_hide_show',array(
    'label' => esc_html__( 'Show / Hide Sidebar','vw-maintenance-services' ),
    'section' => 'vw_maintenance_services_responsive_media'
  )));

  $wp_customize->add_setting( 'vw_maintenance_services_resp_scroll_top_hide_show',array(
    'default' => 1,
    'transport' => 'refresh',
    'sanitize_callback' => 'vw_maintenance_services_switch_sanitization'
  ));  
  $wp_customize->add_control( new VW_Maintenance_Services_Toggle_Switch_Custom_Control( $wp_customize, 'vw_maintenance_services_resp_scroll_top_hide_show',array(
    'label' => esc_html__( 'Show / Hide Scroll To Top','vw-maintenance-services' ),
    'section' => 'vw_maintenance_services_responsive_media'
  )));

  $wp_customize->add_setting('vw_maintenance_services_res_menus_open_icon',array(
		'default'	=> 'fas fa-bars',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new VW_Maintenance_Services_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_maintenance_services_res_menus_open_icon',array(
		'label'	=> __('Add Open Menu Icon','vw-maintenance-services'),
		'transport' => 'refresh',
		'section'	=> 'vw_maintenance_services_responsive_media',
		'setting'	=> 'vw_maintenance_services_res_menus_open_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('vw_maintenance_services_res_close_menus_icon',array(
		'default'	=> 'fas fa-times',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new VW_Maintenance_Services_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_maintenance_services_res_close_menus_icon',array(
		'label'	=> __('Add Close Menu Icon','vw-maintenance-services'),
		'transport' => 'refresh',
		'section'	=> 'vw_maintenance_services_responsive_media',
		'setting'	=> 'vw_maintenance_services_res_close_menus_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('vw_maintenance_services_resp_menu_toggle_btn_bg_color', array(
		'default'           => '#42cfc4',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'vw_maintenance_services_resp_menu_toggle_btn_bg_color', array(
		'label'    => __('Toggle Button Bg Color', 'vw-maintenance-services'),
		'section'  => 'vw_maintenance_services_responsive_media',
	)));

  //Woocommerce settings
	$wp_customize->add_section('vw_maintenance_services_woocommerce_section', array(
		'title'    => __('WooCommerce Layout', 'vw-maintenance-services'),
		'priority' => null,
		'panel'    => 'woocommerce',
	));

  //Shop Page Featured Image
	$wp_customize->add_setting( 'vw_maintenance_services_shop_featured_image_border_radius', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_maintenance_services_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_maintenance_services_shop_featured_image_border_radius', array(
		'label'       => esc_html__( 'Shop Page Featured Image Border Radius','vw-maintenance-services' ),
		'section'     => 'vw_maintenance_services_woocommerce_section',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting( 'vw_maintenance_services_shop_featured_image_box_shadow', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_maintenance_services_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_maintenance_services_shop_featured_image_box_shadow', array(
		'label'       => esc_html__( 'Shop Page Featured Image Box Shadow','vw-maintenance-services' ),
		'section'     => 'vw_maintenance_services_woocommerce_section',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'vw_maintenance_services_woocommerce_shop_page_sidebar', array( 'selector' => '.post-type-archive-product #sidebar', 
		'render_callback' => 'vw_maintenance_services_customize_partial_vw_maintenance_services_woocommerce_shop_page_sidebar', ) );

  //Woocommerce Shop Page Sidebar
	$wp_customize->add_setting( 'vw_maintenance_services_woocommerce_shop_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_maintenance_services_switch_sanitization'
  ) );
  $wp_customize->add_control( new VW_Maintenance_Services_Toggle_Switch_Custom_Control( $wp_customize, 'vw_maintenance_services_woocommerce_shop_page_sidebar',array(
		'label' => esc_html__( 'Shop Page Sidebar','vw-maintenance-services' ),
		'section' => 'vw_maintenance_services_woocommerce_section'
  )));

  $wp_customize->add_setting('vw_maintenance_services_shop_page_layout',array(
    'default' => 'Right Sidebar',
    'sanitize_callback' => 'vw_maintenance_services_sanitize_choices'
	));
	$wp_customize->add_control('vw_maintenance_services_shop_page_layout',array(
    'type' => 'select',
    'label' => __('Shop Page Sidebar Layout','vw-maintenance-services'),
    'section' => 'vw_maintenance_services_woocommerce_section',
    'choices' => array(
        'Left Sidebar' => __('Left Sidebar','vw-maintenance-services'),
        'Right Sidebar' => __('Right Sidebar','vw-maintenance-services'),
        ),
	) );

  //Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'vw_maintenance_services_woocommerce_single_product_page_sidebar', array( 'selector' => '.single-product #sidebar', 
		'render_callback' => 'vw_maintenance_services_customize_partial_vw_maintenance_services_woocommerce_single_product_page_sidebar', ) 		);

    //Woocommerce Single Product page Sidebar
	$wp_customize->add_setting( 'vw_maintenance_services_woocommerce_single_product_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_maintenance_services_switch_sanitization'
  ) );
  $wp_customize->add_control( new VW_Maintenance_Services_Toggle_Switch_Custom_Control( $wp_customize, 'vw_maintenance_services_woocommerce_single_product_page_sidebar',array(
		'label' => esc_html__( 'Single Product Sidebar','vw-maintenance-services' ),
		'section' => 'vw_maintenance_services_woocommerce_section'
  )));

 	$wp_customize->add_setting('vw_maintenance_services_single_product_layout',array(
    'default' => 'Right Sidebar',
    'sanitize_callback' => 'vw_maintenance_services_sanitize_choices'
	));
	$wp_customize->add_control('vw_maintenance_services_single_product_layout',array(
    'type' => 'select',
    'label' => __('Single Product Sidebar Layout','vw-maintenance-services'),
    'section' => 'vw_maintenance_services_woocommerce_section',
    'choices' => array(
        'Left Sidebar' => __('Left Sidebar','vw-maintenance-services'),
        'Right Sidebar' => __('Right Sidebar','vw-maintenance-services'),
    ),
	) );

  //Products per page
  $wp_customize->add_setting('vw_maintenance_services_products_per_page',array(
		'default'=> '9',
		'sanitize_callback'	=> 'vw_maintenance_services_sanitize_float'
	));
	$wp_customize->add_control('vw_maintenance_services_products_per_page',array(
		'label'	=> __('Products Per Page','vw-maintenance-services'),
		'description' => __('Display on shop page','vw-maintenance-services'),
		'input_attrs' => array(
      'step'             => 1,
			'min'              => 0,
			'max'              => 50,
        ),
		'section'=> 'vw_maintenance_services_woocommerce_section',
		'type'=> 'number',
	));

  //Products per row
  $wp_customize->add_setting('vw_maintenance_services_products_per_row',array(
		'default'=> '3',
		'sanitize_callback'	=> 'vw_maintenance_services_sanitize_choices'
	));
	$wp_customize->add_control('vw_maintenance_services_products_per_row',array(
		'label'	=> __('Products Per Row','vw-maintenance-services'),
		'description' => __('Display on shop page','vw-maintenance-services'),
		'choices' => array(
            '2' => '2',
						'3' => '3',
						'4' => '4',
		),
		'section'=> 'vw_maintenance_services_woocommerce_section',
		'type'=> 'select',
	));

	//Products padding
	$wp_customize->add_setting('vw_maintenance_services_products_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_products_padding_top_bottom',array(
		'label'	=> __('Products Padding Top Bottom','vw-maintenance-services'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-maintenance-services'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-maintenance-services' ),
        ),
		'section'=> 'vw_maintenance_services_woocommerce_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_maintenance_services_products_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_products_padding_left_right',array(
		'label'	=> __('Products Padding Left Right','vw-maintenance-services'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-maintenance-services'),
		'input_attrs' => array(
    'placeholder' => __( '10px', 'vw-maintenance-services' ),
        ),
		'section'=> 'vw_maintenance_services_woocommerce_section',
		'type'=> 'text'
	));

	//Products box shadow
	$wp_customize->add_setting( 'vw_maintenance_services_products_box_shadow', array(
		'default'              => '',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_maintenance_services_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_maintenance_services_products_box_shadow', array(
		'label'       => esc_html__( 'Products Box Shadow','vw-maintenance-services' ),
		'section'     => 'vw_maintenance_services_woocommerce_section',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	//Products border radius
  $wp_customize->add_setting( 'vw_maintenance_services_products_border_radius', array(
		'default'              => '',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_maintenance_services_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_maintenance_services_products_border_radius', array(
		'label'       => esc_html__( 'Products Border Radius','vw-maintenance-services' ),
		'section'     => 'vw_maintenance_services_woocommerce_section',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting('vw_maintenance_services_products_btn_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_products_btn_padding_top_bottom',array(
		'label'	=> __('Products Button Padding Top Bottom','vw-maintenance-services'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-maintenance-services'),
		'input_attrs' => array(
    'placeholder' => __( '10px', 'vw-maintenance-services' ),
        ),
		'section'=> 'vw_maintenance_services_woocommerce_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_maintenance_services_products_btn_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_products_btn_padding_left_right',array(
		'label'	=> __('Products Button Padding Left Right','vw-maintenance-services'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-maintenance-services'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-maintenance-services' ),
        ),
		'section'=> 'vw_maintenance_services_woocommerce_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'vw_maintenance_services_products_button_border_radius', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_maintenance_services_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_maintenance_services_products_button_border_radius', array(
		'label'       => esc_html__( 'Products Button Border Radius','vw-maintenance-services' ),
		'section'     => 'vw_maintenance_services_woocommerce_section',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	//Products Sale Badge
	$wp_customize->add_setting('vw_maintenance_services_woocommerce_sale_position',array(
    'default' => 'right',
    'sanitize_callback' => 'vw_maintenance_services_sanitize_choices'
	));
	$wp_customize->add_control('vw_maintenance_services_woocommerce_sale_position',array(
    'type' => 'select',
    'label' => __('Sale Badge Position','vw-maintenance-services'),
    'section' => 'vw_maintenance_services_woocommerce_section',
    'choices' => array(
        'left' => __('Left','vw-maintenance-services'),
        'right' => __('Right','vw-maintenance-services'),
        ),
	) );

	$wp_customize->add_setting('vw_maintenance_services_woocommerce_sale_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_woocommerce_sale_font_size',array(
		'label'	=> __('Sale Font Size','vw-maintenance-services'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-maintenance-services'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-maintenance-services' ),
        ),
		'section'=> 'vw_maintenance_services_woocommerce_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_maintenance_services_woocommerce_sale_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_woocommerce_sale_padding_top_bottom',array(
		'label'	=> __('Sale Padding Top Bottom','vw-maintenance-services'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-maintenance-services'),
		'input_attrs' => array(
    'placeholder' => __( '10px', 'vw-maintenance-services' ),
        ),
		'section'=> 'vw_maintenance_services_woocommerce_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_maintenance_services_woocommerce_sale_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_maintenance_services_woocommerce_sale_padding_left_right',array(
		'label'	=> __('Sale Padding Left Right','vw-maintenance-services'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-maintenance-services'),
		'input_attrs' => array(
    'placeholder' => __( '10px', 'vw-maintenance-services' ),
        ),
		'section'=> 'vw_maintenance_services_woocommerce_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'vw_maintenance_services_woocommerce_sale_border_radius', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_maintenance_services_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_maintenance_services_woocommerce_sale_border_radius', array(
		'label'       => esc_html__( 'Sale Border Radius','vw-maintenance-services' ),
		'section'     => 'vw_maintenance_services_woocommerce_section',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	// Related Product
  $wp_customize->add_setting( 'vw_maintenance_services_related_product_show_hide',array(
	  'default' => 1,
	  'transport' => 'refresh',
	  'sanitize_callback' => 'vw_maintenance_services_switch_sanitization'
  ) );
  $wp_customize->add_control( new VW_Maintenance_Services_Toggle_Switch_Custom_Control( $wp_customize, 'vw_maintenance_services_related_product_show_hide',array(
      'label' => esc_html__( 'Related product','vw-maintenance-services' ),
      'section' => 'vw_maintenance_services_woocommerce_section'
  )));

  // Has to be at the top
	$wp_customize->register_panel_type( 'VW_Maintenance_Services_WP_Customize_Panel' );
	$wp_customize->register_section_type( 'VW_Maintenance_Services_WP_Customize_Section' );
}

add_action( 'customize_register', 'vw_maintenance_services_customize_register' );

load_template( trailingslashit( get_template_directory() ) . '/inc/logo/logo-resizer.php' );

if ( class_exists( 'WP_Customize_Panel' ) ) {
  	class VW_Maintenance_Services_WP_Customize_Panel extends WP_Customize_Panel {
	    public $panel;
	    public $type = 'vw_maintenance_services_panel';
	    public function json() {

	      $array = wp_array_slice_assoc( (array) $this, array( 'id', 'description', 'priority', 'type', 'panel', ) );
	      $array['title'] = html_entity_decode( $this->title, ENT_QUOTES, get_bloginfo( 'charset' ) );
	      $array['content'] = $this->get_content();
	      $array['active'] = $this->active();
	      $array['instanceNumber'] = $this->instance_number;
	      return $array;
    	}
  	}
}

if ( class_exists( 'WP_Customize_Section' ) ) {
  	class VW_Maintenance_Services_WP_Customize_Section extends WP_Customize_Section {
	    public $section;
	    public $type = 'vw_maintenance_services_section';
	    public function json() {

	      $array = wp_array_slice_assoc( (array) $this, array( 'id', 'description', 'priority', 'panel', 'type', 'description_hidden', 'section', ) );
	      $array['title'] = html_entity_decode( $this->title, ENT_QUOTES, get_bloginfo( 'charset' ) );
	      $array['content'] = $this->get_content();
	      $array['active'] = $this->active();
	      $array['instanceNumber'] = $this->instance_number;

	      if ( $this->panel ) {
	        $array['customizeAction'] = sprintf( 'Customizing &#9656; %s', esc_html( $this->manager->get_panel( $this->panel )->title ) );
	      } else {
	        $array['customizeAction'] = 'Customizing';
	      }
	      return $array;
    	}
  	}
}

// Enqueue our scripts and styles
function vw_maintenance_services_customize_controls_scripts() {
  wp_enqueue_script( 'customizer-controls', get_theme_file_uri( '/assets/js/customizer-controls.js' ), array(), '1.0', true );
}
add_action( 'customize_controls_enqueue_scripts', 'vw_maintenance_services_customize_controls_scripts' );

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class VW_Maintenance_Services_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	 */
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'VW_Maintenance_Services_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section(new VW_Maintenance_Services_Customize_Section_Pro($manager,'vw_maintenance_services_upgrade_pro_link',array(
			'priority'   => 1,
			'title'    => esc_html__( 'VW Maintenance Pro', 'vw-maintenance-services' ),
			'pro_text' => esc_html__( 'UPGRADE PRO', 'vw-maintenance-services' ),
			'pro_url'  => esc_url('https://www.vwthemes.com/themes/wordpress-maintenance-service-theme/'),
		)));

		// Register sections.
		$manager->add_section(new VW_Maintenance_Services_Customize_Section_Pro($manager,'vw_maintenance_services_get_started_link',array(
			'priority'   => 1,
			'title'    => esc_html__( 'Documentation', 'vw-maintenance-services' ),
			'pro_text' => esc_html__( 'Docs', 'vw-maintenance-services' ),
			'pro_url'  => esc_url('https://preview.vwthemesdemo.com/docs/free-vw-maintenance-service/'),
		)));
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'vw-maintenance-services-customize-controls', trailingslashit( esc_url(get_template_directory_uri()) ) . '/assets/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'vw-maintenance-services-customize-controls', trailingslashit( esc_url(get_template_directory_uri()) ) . '/assets/css/customize-controls.css' );
	}
}

// Doing this customizer thang!
VW_Maintenance_Services_Customize::get_instance();